# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/skill/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/skill/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.skill.v1 import status_pb2 as ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_status__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ai/stigmer/agentic/skill/v1/io.proto\x12\x1b\x61i.stigmer.agentic.skill.v1\x1a(ai/stigmer/agentic/skill/v1/status.proto\x1a\x1b\x62uf/validate/validate.proto\"\'\n\x07SkillId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\xd8\x01\n\x10PushSkillRequest\x12\x18\n\x03org\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x03org\x12\"\n\x08\x61rtifact\x18\x02 \x01(\x0c\x42\x06\xbaH\x03\xc8\x01\x01R\x08\x61rtifact\x12-\n\x03tag\x18\x03 \x01(\tB\x1b\xbaH\x18r\x16\x32\x14^$|^[a-zA-Z0-9._-]+$R\x03tag\x12Q\n\x0egit_provenance\x18\x04 \x01(\x0b\x32*.ai.stigmer.agentic.skill.v1.GitProvenanceR\rgitProvenanceJ\x04\x08\x05\x10\x06\"\xc6\x01\n%PushSkillFromExecutionArtifactRequest\x12\x18\n\x03org\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x03org\x12*\n\x0c\x65xecution_id\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x65xecutionId\x12(\n\x0bstorage_key\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\nstorageKey\x12-\n\x03tag\x18\x04 \x01(\tB\x1b\xbaH\x18r\x16\x32\x14^$|^[a-zA-Z0-9._-]+$R\x03tag\"N\n\x12GetArtifactRequest\x12\x38\n\x14\x61rtifact_storage_key\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x12\x61rtifactStorageKey\"1\n\x13GetArtifactResponse\x12\x1a\n\x08\x61rtifact\x18\x01 \x01(\x0cR\x08\x61rtifactB\xbb\x01\n\x1f\x63om.ai.stigmer.agentic.skill.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SAS\xaa\x02\x1b\x41i.Stigmer.Agentic.Skill.V1\xca\x02\x1b\x41i\\Stigmer\\Agentic\\Skill\\V1\xe2\x02\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Agentic::Skill::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.skill.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.agentic.skill.v1B\007IoProtoP\001\242\002\004ASAS\252\002\033Ai.Stigmer.Agentic.Skill.V1\312\002\033Ai\\Stigmer\\Agentic\\Skill\\V1\342\002\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Agentic::Skill::V1'
  _globals['_SKILLID'].fields_by_name['value']._loaded_options = None
  _globals['_SKILLID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PUSHSKILLREQUEST'].fields_by_name['org']._loaded_options = None
  _globals['_PUSHSKILLREQUEST'].fields_by_name['org']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PUSHSKILLREQUEST'].fields_by_name['artifact']._loaded_options = None
  _globals['_PUSHSKILLREQUEST'].fields_by_name['artifact']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PUSHSKILLREQUEST'].fields_by_name['tag']._loaded_options = None
  _globals['_PUSHSKILLREQUEST'].fields_by_name['tag']._serialized_options = b'\272H\030r\0262\024^$|^[a-zA-Z0-9._-]+$'
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['org']._loaded_options = None
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['org']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['execution_id']._loaded_options = None
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['storage_key']._loaded_options = None
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['storage_key']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['tag']._loaded_options = None
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['tag']._serialized_options = b'\272H\030r\0262\024^$|^[a-zA-Z0-9._-]+$'
  _globals['_GETARTIFACTREQUEST'].fields_by_name['artifact_storage_key']._loaded_options = None
  _globals['_GETARTIFACTREQUEST'].fields_by_name['artifact_storage_key']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SKILLID']._serialized_start=140
  _globals['_SKILLID']._serialized_end=179
  _globals['_PUSHSKILLREQUEST']._serialized_start=182
  _globals['_PUSHSKILLREQUEST']._serialized_end=398
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST']._serialized_start=401
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST']._serialized_end=599
  _globals['_GETARTIFACTREQUEST']._serialized_start=601
  _globals['_GETARTIFACTREQUEST']._serialized_end=679
  _globals['_GETARTIFACTRESPONSE']._serialized_start=681
  _globals['_GETARTIFACTRESPONSE']._serialized_end=730
# @@protoc_insertion_point(module_scope)
