# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/environment/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/environment/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.environment.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_environment_dot_v1_dot_api__pb2
from ai.stigmer.agentic.environment.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_environment_dot_v1_dot_spec__pb2
from ai.stigmer.commons.rpc import pagination_pb2 as ai_dot_stigmer_dot_commons_dot_rpc_dot_pagination__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ai/stigmer/agentic/environment/v1/io.proto\x12!ai.stigmer.agentic.environment.v1\x1a+ai/stigmer/agentic/environment/v1/api.proto\x1a,ai/stigmer/agentic/environment/v1/spec.proto\x1a\'ai/stigmer/commons/rpc/pagination.proto\x1a\x1b\x62uf/validate/validate.proto\"-\n\rEnvironmentId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"h\n\x1b\x45nvironmentSecretValueInput\x12.\n\x0e\x65nvironment_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\renvironmentId\x12\x19\n\x03key\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x03key\"\x8e\x02\n\x17ListEnvironmentsRequest\x12\x19\n\x03org\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x03org\x12^\n\x06labels\x18\x02 \x03(\x0b\x32\x46.ai.stigmer.agentic.environment.v1.ListEnvironmentsRequest.LabelsEntryR\x06labels\x12=\n\tpage_info\x18\x03 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x08pageInfo\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"x\n\x0f\x45nvironmentList\x12\x1f\n\x0btotal_count\x18\x01 \x01(\x05R\ntotalCount\x12\x44\n\x05items\x18\x02 \x03(\x0b\x32..ai.stigmer.agentic.environment.v1.EnvironmentR\x05items\"\xb9\x02\n!UpdateEnvironmentVariablesRequest\x12.\n\x0e\x65nvironment_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\renvironmentId\x12q\n\tvariables\x18\x02 \x03(\x0b\x32S.ai.stigmer.agentic.environment.v1.UpdateEnvironmentVariablesRequest.VariablesEntryR\tvariables\x1aq\n\x0eVariablesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12I\n\x05value\x18\x02 \x01(\x0b\x32\x33.ai.stigmer.agentic.environment.v1.EnvironmentValueR\x05value:\x02\x38\x01\"q\n!RemoveEnvironmentVariablesRequest\x12.\n\x0e\x65nvironment_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\renvironmentId\x12\x1c\n\x04keys\x18\x02 \x03(\tB\x08\xbaH\x05\x92\x01\x02\x08\x01R\x04keysB\xd9\x01\n%com.ai.stigmer.agentic.environment.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SAE\xaa\x02!Ai.Stigmer.Agentic.Environment.V1\xca\x02!Ai\\Stigmer\\Agentic\\Environment\\V1\xe2\x02-Ai\\Stigmer\\Agentic\\Environment\\V1\\GPBMetadata\xea\x02%Ai::Stigmer::Agentic::Environment::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.environment.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.ai.stigmer.agentic.environment.v1B\007IoProtoP\001\242\002\004ASAE\252\002!Ai.Stigmer.Agentic.Environment.V1\312\002!Ai\\Stigmer\\Agentic\\Environment\\V1\342\002-Ai\\Stigmer\\Agentic\\Environment\\V1\\GPBMetadata\352\002%Ai::Stigmer::Agentic::Environment::V1'
  _globals['_ENVIRONMENTID'].fields_by_name['value']._loaded_options = None
  _globals['_ENVIRONMENTID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_ENVIRONMENTSECRETVALUEINPUT'].fields_by_name['environment_id']._loaded_options = None
  _globals['_ENVIRONMENTSECRETVALUEINPUT'].fields_by_name['environment_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_ENVIRONMENTSECRETVALUEINPUT'].fields_by_name['key']._loaded_options = None
  _globals['_ENVIRONMENTSECRETVALUEINPUT'].fields_by_name['key']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_LISTENVIRONMENTSREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_LISTENVIRONMENTSREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['org']._loaded_options = None
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['org']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST_VARIABLESENTRY']._loaded_options = None
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST'].fields_by_name['environment_id']._loaded_options = None
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST'].fields_by_name['environment_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_REMOVEENVIRONMENTVARIABLESREQUEST'].fields_by_name['environment_id']._loaded_options = None
  _globals['_REMOVEENVIRONMENTVARIABLESREQUEST'].fields_by_name['environment_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_REMOVEENVIRONMENTVARIABLESREQUEST'].fields_by_name['keys']._loaded_options = None
  _globals['_REMOVEENVIRONMENTVARIABLESREQUEST'].fields_by_name['keys']._serialized_options = b'\272H\005\222\001\002\010\001'
  _globals['_ENVIRONMENTID']._serialized_start=242
  _globals['_ENVIRONMENTID']._serialized_end=287
  _globals['_ENVIRONMENTSECRETVALUEINPUT']._serialized_start=289
  _globals['_ENVIRONMENTSECRETVALUEINPUT']._serialized_end=393
  _globals['_LISTENVIRONMENTSREQUEST']._serialized_start=396
  _globals['_LISTENVIRONMENTSREQUEST']._serialized_end=666
  _globals['_LISTENVIRONMENTSREQUEST_LABELSENTRY']._serialized_start=609
  _globals['_LISTENVIRONMENTSREQUEST_LABELSENTRY']._serialized_end=666
  _globals['_ENVIRONMENTLIST']._serialized_start=668
  _globals['_ENVIRONMENTLIST']._serialized_end=788
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST']._serialized_start=791
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST']._serialized_end=1104
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST_VARIABLESENTRY']._serialized_start=991
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST_VARIABLESENTRY']._serialized_end=1104
  _globals['_REMOVEENVIRONMENTVARIABLESREQUEST']._serialized_start=1106
  _globals['_REMOVEENVIRONMENTVARIABLESREQUEST']._serialized_end=1219
# @@protoc_insertion_point(module_scope)
