# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/environment/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/environment/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.environment.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_environment_dot_v1_dot_api__pb2
from ai.stigmer.agentic.environment.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_environment_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/ai/stigmer/agentic/environment/v1/command.proto\x12!ai.stigmer.agentic.environment.v1\x1a+ai/stigmer/agentic/environment/v1/api.proto\x1a*ai/stigmer/agentic/environment/v1/io.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xc1\x08\n\x1c\x45nvironmentCommandController\x12g\n\x05\x61pply\x12..ai.stigmer.agentic.environment.v1.Environment\x1a..ai.stigmer.agentic.environment.v1.Environment\x12\xb9\x01\n\x06\x63reate\x12..ai.stigmer.agentic.environment.v1.Environment\x1a..ai.stigmer.agentic.environment.v1.Environment\"O\xc2\xb8\x18K\x08\x1b\x10\x1e\"\x0cmetadata.org*7unauthorized to create environment in this organization\x12\xa3\x01\n\x06update\x12..ai.stigmer.agentic.environment.v1.Environment\x1a..ai.stigmer.agentic.environment.v1.Environment\"9\xc2\xb8\x18\x35\x08\x04\x10\x35\"\x0bmetadata.id*\"unauthorized to update environment\x12\xab\x01\n\x06\x64\x65lete\x12\x36.ai.stigmer.commons.apiresource.ApiResourceDeleteInput\x1a..ai.stigmer.agentic.environment.v1.Environment\"9\xc2\xb8\x18\x35\x08\x04\x10\x35\"\x0bmetadata.id*\"unauthorized to delete environment\x12\xcf\x01\n\x0fupdateVariables\x12\x44.ai.stigmer.agentic.environment.v1.UpdateEnvironmentVariablesRequest\x1a..ai.stigmer.agentic.environment.v1.Environment\"F\xc2\xb8\x18\x42\x08\x04\x10\x35\"\x0e\x65nvironment_id*,unauthorized to update environment variables\x12\xcf\x01\n\x0fremoveVariables\x12\x44.ai.stigmer.agentic.environment.v1.RemoveEnvironmentVariablesRequest\x1a..ai.stigmer.agentic.environment.v1.Environment\"F\xc2\xb8\x18\x42\x08\x04\x10\x35\"\x0e\x65nvironment_id*,unauthorized to remove environment variables\x1a\x04\xa0\xff+5B\xde\x01\n%com.ai.stigmer.agentic.environment.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SAE\xaa\x02!Ai.Stigmer.Agentic.Environment.V1\xca\x02!Ai\\Stigmer\\Agentic\\Environment\\V1\xe2\x02-Ai\\Stigmer\\Agentic\\Environment\\V1\\GPBMetadata\xea\x02%Ai::Stigmer::Agentic::Environment::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.environment.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.ai.stigmer.agentic.environment.v1B\014CommandProtoP\001\242\002\004ASAE\252\002!Ai.Stigmer.Agentic.Environment.V1\312\002!Ai\\Stigmer\\Agentic\\Environment\\V1\342\002-Ai\\Stigmer\\Agentic\\Environment\\V1\\GPBMetadata\352\002%Ai::Stigmer::Agentic::Environment::V1'
  _globals['_ENVIRONMENTCOMMANDCONTROLLER']._loaded_options = None
  _globals['_ENVIRONMENTCOMMANDCONTROLLER']._serialized_options = b'\240\377+5'
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\302\270\030K\010\033\020\036\"\014metadata.org*7unauthorized to create environment in this organization'
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['update']._loaded_options = None
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['update']._serialized_options = b'\302\270\0305\010\004\0205\"\013metadata.id*\"unauthorized to update environment'
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\0305\010\004\0205\"\013metadata.id*\"unauthorized to delete environment'
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['updateVariables']._loaded_options = None
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['updateVariables']._serialized_options = b'\302\270\030B\010\004\0205\"\016environment_id*,unauthorized to update environment variables'
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['removeVariables']._loaded_options = None
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['removeVariables']._serialized_options = b'\302\270\030B\010\004\0205\"\016environment_id*,unauthorized to remove environment variables'
  _globals['_ENVIRONMENTCOMMANDCONTROLLER']._serialized_start=342
  _globals['_ENVIRONMENTCOMMANDCONTROLLER']._serialized_end=1431
# @@protoc_insertion_point(module_scope)
