# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/mcpserver/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/mcpserver/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.mcpserver.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2
from ai.stigmer.agentic.mcpserver.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ai/stigmer/agentic/mcpserver/v1/command.proto\x12\x1f\x61i.stigmer.agentic.mcpserver.v1\x1a)ai/stigmer/agentic/mcpserver/v1/api.proto\x1a(ai/stigmer/agentic/mcpserver/v1/io.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xc8\x07\n\x1aMcpServerCommandController\x12_\n\x05\x61pply\x12*.ai.stigmer.agentic.mcpserver.v1.McpServer\x1a*.ai.stigmer.agentic.mcpserver.v1.McpServer\x12\x66\n\x06\x63reate\x12*.ai.stigmer.agentic.mcpserver.v1.McpServer\x1a*.ai.stigmer.agentic.mcpserver.v1.McpServer\"\x04\xd0\xb8\x18\x01\x12\x9a\x01\n\x06update\x12*.ai.stigmer.agentic.mcpserver.v1.McpServer\x1a*.ai.stigmer.agentic.mcpserver.v1.McpServer\"8\xc2\xb8\x18\x34\x08\x04\x10,\"\x0bmetadata.id*!unauthorized to update mcp server\x12\xa6\x01\n\x06\x64\x65lete\x12\x36.ai.stigmer.commons.apiresource.ApiResourceDeleteInput\x1a*.ai.stigmer.agentic.mcpserver.v1.McpServer\"8\xc2\xb8\x18\x34\x08\x02\x10,\"\x0bresource_id*!unauthorized to delete mcp server\x12\xba\x01\n\x10updateVisibility\x12\x35.ai.stigmer.commons.apiresource.UpdateVisibilityInput\x1a*.ai.stigmer.agentic.mcpserver.v1.McpServer\"C\xc2\xb8\x18?\x08\x04\x10,\"\x0bresource_id*,unauthorized to update mcp server visibility\x12\xd7\x01\n\x1cupdateDiscoveredCapabilities\x12\x42.ai.stigmer.agentic.mcpserver.v1.UpdateDiscoveredCapabilitiesInput\x1a*.ai.stigmer.agentic.mcpserver.v1.McpServer\"G\xc2\xb8\x18\x43\x08\x04\x10,\"\rmcp_server_id*.unauthorized to update mcp server capabilities\x1a\x04\xa0\xff+,B\xd4\x01\n#com.ai.stigmer.agentic.mcpserver.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SAM\xaa\x02\x1f\x41i.Stigmer.Agentic.Mcpserver.V1\xca\x02\x1f\x41i\\Stigmer\\Agentic\\Mcpserver\\V1\xe2\x02+Ai\\Stigmer\\Agentic\\Mcpserver\\V1\\GPBMetadata\xea\x02#Ai::Stigmer::Agentic::Mcpserver::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.mcpserver.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.ai.stigmer.agentic.mcpserver.v1B\014CommandProtoP\001\242\002\004ASAM\252\002\037Ai.Stigmer.Agentic.Mcpserver.V1\312\002\037Ai\\Stigmer\\Agentic\\Mcpserver\\V1\342\002+Ai\\Stigmer\\Agentic\\Mcpserver\\V1\\GPBMetadata\352\002#Ai::Stigmer::Agentic::Mcpserver::V1'
  _globals['_MCPSERVERCOMMANDCONTROLLER']._loaded_options = None
  _globals['_MCPSERVERCOMMANDCONTROLLER']._serialized_options = b'\240\377+,'
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\320\270\030\001'
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['update']._loaded_options = None
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['update']._serialized_options = b'\302\270\0304\010\004\020,\"\013metadata.id*!unauthorized to update mcp server'
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\0304\010\002\020,\"\013resource_id*!unauthorized to delete mcp server'
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['updateVisibility']._loaded_options = None
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['updateVisibility']._serialized_options = b'\302\270\030?\010\004\020,\"\013resource_id*,unauthorized to update mcp server visibility'
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['updateDiscoveredCapabilities']._loaded_options = None
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['updateDiscoveredCapabilities']._serialized_options = b'\302\270\030C\010\004\020,\"\rmcp_server_id*.unauthorized to update mcp server capabilities'
  _globals['_MCPSERVERCOMMANDCONTROLLER']._serialized_start=334
  _globals['_MCPSERVERCOMMANDCONTROLLER']._serialized_end=1302
# @@protoc_insertion_point(module_scope)
