# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/usage.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/usage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ai/stigmer/agentic/agentexecution/v1/usage.proto\x12$ai.stigmer.agentic.agentexecution.v1\"\xad\x06\n\x0cUsageMetrics\x12#\n\rprompt_tokens\x18\x01 \x01(\x05R\x0cpromptTokens\x12+\n\x11\x63ompletion_tokens\x18\x02 \x01(\x05R\x10\x63ompletionTokens\x12!\n\x0ctotal_tokens\x18\x03 \x01(\x05R\x0btotalTokens\x12$\n\x0ellm_call_count\x18\x04 \x01(\x05R\x0cllmCallCount\x12#\n\rprimary_model\x18\x05 \x01(\tR\x0cprimaryModel\x12\x32\n\x15\x63\x61\x63he_creation_tokens\x18\x06 \x01(\x05R\x13\x63\x61\x63heCreationTokens\x12*\n\x11\x63\x61\x63he_read_tokens\x18\x07 \x01(\x05R\x0f\x63\x61\x63heReadTokens\x12Y\n\x0fmodel_breakdown\x18\x08 \x03(\x0b\x32\x30.ai.stigmer.agentic.agentexecution.v1.ModelUsageR\x0emodelBreakdown\x12,\n\x12\x65stimated_cost_usd\x18\t \x01(\x01R\x10\x65stimatedCostUsd\x12=\n\x1btool_result_chars_truncated\x18\n \x01(\x03R\x18toolResultCharsTruncated\x12Q\n\tllm_calls\x18\x0b \x03(\x0b\x32\x34.ai.stigmer.agentic.agentexecution.v1.LlmCallMetricsR\x08llmCalls\x12*\n\x11total_duration_ms\x18\x0c \x01(\x05R\x0ftotalDurationMs\x12&\n\x0fllm_duration_ms\x18\r \x01(\x05R\rllmDurationMs\x12(\n\x10tool_duration_ms\x18\x0e \x01(\x05R\x0etoolDurationMs\x12\x39\n\x19\x61pproval_wait_duration_ms\x18\x0f \x01(\x05R\x16\x61pprovalWaitDurationMs\x12)\n\x10primary_provider\x18\x10 \x01(\tR\x0fprimaryProvider\"\xab\x04\n\nModelUsage\x12\x14\n\x05model\x18\x01 \x01(\tR\x05model\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12!\n\x0cinput_tokens\x18\x03 \x01(\x05R\x0binputTokens\x12#\n\routput_tokens\x18\x04 \x01(\x05R\x0coutputTokens\x12\x32\n\x15\x63\x61\x63he_creation_tokens\x18\x05 \x01(\x05R\x13\x63\x61\x63heCreationTokens\x12*\n\x11\x63\x61\x63he_read_tokens\x18\x06 \x01(\x05R\x0f\x63\x61\x63heReadTokens\x12\x1d\n\ncall_count\x18\x07 \x01(\x05R\tcallCount\x12\x35\n\x17input_price_per_million\x18\x08 \x01(\x01R\x14inputPricePerMillion\x12\x37\n\x18output_price_per_million\x18\t \x01(\x01R\x15outputPricePerMillion\x12\x46\n cache_creation_price_per_million\x18\n \x01(\x01R\x1c\x63\x61\x63heCreationPricePerMillion\x12>\n\x1c\x63\x61\x63he_read_price_per_million\x18\x0b \x01(\x01R\x18\x63\x61\x63heReadPricePerMillion\x12,\n\x12\x65stimated_cost_usd\x18\x0c \x01(\x01R\x10\x65stimatedCostUsd\"\xf3\x02\n\x0eLlmCallMetrics\x12\x1a\n\x08sequence\x18\x01 \x01(\x05R\x08sequence\x12\x14\n\x05model\x18\x02 \x01(\tR\x05model\x12\x1a\n\x08provider\x18\x03 \x01(\tR\x08provider\x12!\n\x0cinput_tokens\x18\x04 \x01(\x05R\x0binputTokens\x12#\n\routput_tokens\x18\x05 \x01(\x05R\x0coutputTokens\x12\x32\n\x15\x63\x61\x63he_creation_tokens\x18\x06 \x01(\x05R\x13\x63\x61\x63heCreationTokens\x12*\n\x11\x63\x61\x63he_read_tokens\x18\x07 \x01(\x05R\x0f\x63\x61\x63heReadTokens\x12,\n\x12\x65stimated_cost_usd\x18\x08 \x01(\x01R\x10\x65stimatedCostUsd\x12\x1f\n\x0b\x64uration_ms\x18\t \x01(\x05R\ndurationMs\x12\x1c\n\ttimestamp\x18\n \x01(\tR\ttimestampB\xeb\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\nUsageProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.usage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\nUsageProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_USAGEMETRICS']._serialized_start=91
  _globals['_USAGEMETRICS']._serialized_end=904
  _globals['_MODELUSAGE']._serialized_start=907
  _globals['_MODELUSAGE']._serialized_end=1462
  _globals['_LLMCALLMETRICS']._serialized_start=1465
  _globals['_LLMCALLMETRICS']._serialized_end=1836
# @@protoc_insertion_point(module_scope)
