# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/apiresource/apiresourcekind/api_resource_group.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/apiresource/apiresourcekind/api_resource_group.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGai/stigmer/commons/apiresource/apiresourcekind/api_resource_group.proto\x12.ai.stigmer.commons.apiresource.apiresourcekind\x1a google/protobuf/descriptor.proto\"Q\n\x14\x41piResourceGroupMeta\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName*\xba\x01\n\x10\x41piResourceGroup\x12\"\n\x1e\x61pi_resource_group_unspecified\x10\x00\x12.\n\x07\x61gentic\x10\x01\x1a!\xea\xbd,\x1d\n\x12\x61gentic.stigmer.ai\x12\x07\x41gentic\x12\"\n\x03iam\x10\x02\x1a\x19\xea\xbd,\x15\n\x0eiam.stigmer.ai\x12\x03IAM\x12.\n\x07tenancy\x10\x03\x1a!\xea\xbd,\x1d\n\x12tenancy.stigmer.ai\x12\x07Tenancy:\x88\x01\n\ngroup_meta\x12!.google.protobuf.EnumValueOptions\x18\xdd\xc7\x05 \x01(\x0b\x32\x44.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceGroupMetaR\tgroupMetaB\xa9\x02\n2com.ai.stigmer.commons.apiresource.apiresourcekindB\x15\x41piResourceGroupProtoP\x01\xa2\x02\x05\x41SCAA\xaa\x02.Ai.Stigmer.Commons.Apiresource.Apiresourcekind\xca\x02.Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\xe2\x02:Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\\GPBMetadata\xea\x02\x32\x41i::Stigmer::Commons::Apiresource::Apiresourcekindb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.apiresource.apiresourcekind.api_resource_group_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n2com.ai.stigmer.commons.apiresource.apiresourcekindB\025ApiResourceGroupProtoP\001\242\002\005ASCAA\252\002.Ai.Stigmer.Commons.Apiresource.Apiresourcekind\312\002.Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\342\002:Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\\GPBMetadata\352\0022Ai::Stigmer::Commons::Apiresource::Apiresourcekind'
  _globals['_APIRESOURCEGROUP'].values_by_name["agentic"]._loaded_options = None
  _globals['_APIRESOURCEGROUP'].values_by_name["agentic"]._serialized_options = b'\352\275,\035\n\022agentic.stigmer.ai\022\007Agentic'
  _globals['_APIRESOURCEGROUP'].values_by_name["iam"]._loaded_options = None
  _globals['_APIRESOURCEGROUP'].values_by_name["iam"]._serialized_options = b'\352\275,\025\n\016iam.stigmer.ai\022\003IAM'
  _globals['_APIRESOURCEGROUP'].values_by_name["tenancy"]._loaded_options = None
  _globals['_APIRESOURCEGROUP'].values_by_name["tenancy"]._serialized_options = b'\352\275,\035\n\022tenancy.stigmer.ai\022\007Tenancy'
  _globals['_APIRESOURCEGROUP']._serialized_start=241
  _globals['_APIRESOURCEGROUP']._serialized_end=427
  _globals['_APIRESOURCEGROUPMETA']._serialized_start=157
  _globals['_APIRESOURCEGROUPMETA']._serialized_end=238
# @@protoc_insertion_point(module_scope)
