# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/tasks/listen.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/tasks/listen.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import field_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_field__options__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ai/stigmer/agentic/workflow/v1/tasks/listen.proto\x12$ai.stigmer.agentic.workflow.v1.tasks\x1a\x32\x61i/stigmer/commons/apiresource/field_options.proto\x1a\x1b\x62uf/validate/validate.proto\"f\n\x10ListenTaskConfig\x12\x46\n\x02to\x18\x01 \x01(\x0b\x32..ai.stigmer.agentic.workflow.v1.tasks.ListenToB\x06\xbaH\x03\xc8\x01\x01R\x02to:\n\xea\x8b,\x06listen\"\x88\x01\n\x08ListenTo\x12&\n\x04mode\x18\x01 \x01(\tB\x12\xbaH\x0fr\nR\x03oneR\x03\x61ll\xc8\x01\x01R\x04mode\x12T\n\x07signals\x18\x02 \x03(\x0b\x32\x30.ai.stigmer.agentic.workflow.v1.tasks.SignalSpecB\x08\xbaH\x05\x92\x01\x02\x08\x01R\x07signals\"]\n\nSignalSpec\x12\x1a\n\x02id\x18\x01 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x02id\x12\x33\n\x04type\x18\x02 \x01(\tB\x1f\xbaH\x1cr\x17R\x06signalR\x05queryR\x06update\xc8\x01\x01R\x04typeB\xef\x01\n(com.ai.stigmer.agentic.workflow.v1.tasksB\x0bListenProtoP\x01\xa2\x02\x06\x41SAWVT\xaa\x02$Ai.Stigmer.Agentic.Workflow.V1.Tasks\xca\x02$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\xea\x02)Ai::Stigmer::Agentic::Workflow::V1::Tasksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.tasks.listen_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.workflow.v1.tasksB\013ListenProtoP\001\242\002\006ASAWVT\252\002$Ai.Stigmer.Agentic.Workflow.V1.Tasks\312\002$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\342\0020Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\352\002)Ai::Stigmer::Agentic::Workflow::V1::Tasks'
  _globals['_LISTENTASKCONFIG'].fields_by_name['to']._loaded_options = None
  _globals['_LISTENTASKCONFIG'].fields_by_name['to']._serialized_options = b'\272H\003\310\001\001'
  _globals['_LISTENTASKCONFIG']._loaded_options = None
  _globals['_LISTENTASKCONFIG']._serialized_options = b'\352\213,\006listen'
  _globals['_LISTENTO'].fields_by_name['mode']._loaded_options = None
  _globals['_LISTENTO'].fields_by_name['mode']._serialized_options = b'\272H\017r\nR\003oneR\003all\310\001\001'
  _globals['_LISTENTO'].fields_by_name['signals']._loaded_options = None
  _globals['_LISTENTO'].fields_by_name['signals']._serialized_options = b'\272H\005\222\001\002\010\001'
  _globals['_SIGNALSPEC'].fields_by_name['id']._loaded_options = None
  _globals['_SIGNALSPEC'].fields_by_name['id']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_SIGNALSPEC'].fields_by_name['type']._loaded_options = None
  _globals['_SIGNALSPEC'].fields_by_name['type']._serialized_options = b'\272H\034r\027R\006signalR\005queryR\006update\310\001\001'
  _globals['_LISTENTASKCONFIG']._serialized_start=172
  _globals['_LISTENTASKCONFIG']._serialized_end=274
  _globals['_LISTENTO']._serialized_start=277
  _globals['_LISTENTO']._serialized_end=413
  _globals['_SIGNALSPEC']._serialized_start=415
  _globals['_SIGNALSPEC']._serialized_end=508
# @@protoc_insertion_point(module_scope)
