# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.iam.iampolicy.v1.rpcauthorization import io_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_io__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAai/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto\x12,ai.stigmer.iam.iampolicy.v1.rpcauthorization\x1a\x35\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/io.proto\x1a google/protobuf/descriptor.proto:~\n\x06\x63onfig\x12\x1e.google.protobuf.MethodOptions\x18\x88\x87\x03 \x01(\x0b\x32\x44.ai.stigmer.iam.iampolicy.v1.rpcauthorization.RpcAuthorizationConfigR\x06\x63onfig:=\n\tis_public\x12\x1e.google.protobuf.MethodOptions\x18\x89\x87\x03 \x01(\x08R\x08isPublic:T\n\x15is_skip_authorization\x12\x1e.google.protobuf.MethodOptions\x18\x8a\x87\x03 \x01(\x08R\x13isSkipAuthorizationB\x9e\x02\n0com.ai.stigmer.iam.iampolicy.v1.rpcauthorizationB\x12MethodOptionsProtoP\x01\xa2\x02\x06\x41SIIVR\xaa\x02,Ai.Stigmer.Iam.Iampolicy.V1.Rpcauthorization\xca\x02,Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\xe2\x02\x38\x41i\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\\GPBMetadata\xea\x02\x31\x41i::Stigmer::Iam::Iampolicy::V1::Rpcauthorizationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.iampolicy.v1.rpcauthorization.method_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.ai.stigmer.iam.iampolicy.v1.rpcauthorizationB\022MethodOptionsProtoP\001\242\002\006ASIIVR\252\002,Ai.Stigmer.Iam.Iampolicy.V1.Rpcauthorization\312\002,Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\342\0028Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\\GPBMetadata\352\0021Ai::Stigmer::Iam::Iampolicy::V1::Rpcauthorization'
# @@protoc_insertion_point(module_scope)
