# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/tenancy/project/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/tenancy/project/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ai/stigmer/tenancy/project/v1/spec.proto\x12\x1d\x61i.stigmer.tenancy.project.v1\x1a\'ai/stigmer/commons/apiresource/io.proto\"\xa0\x01\n\x0bProjectSpec\x12\x1f\n\x0b\x65ntry_point\x18\x01 \x01(\tR\nentryPoint\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12N\n\x07members\x18\x03 \x03(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceR\x07membersB\xc7\x01\n!com.ai.stigmer.tenancy.project.v1B\tSpecProtoP\x01\xa2\x02\x04\x41STP\xaa\x02\x1d\x41i.Stigmer.Tenancy.Project.V1\xca\x02\x1d\x41i\\Stigmer\\Tenancy\\Project\\V1\xe2\x02)Ai\\Stigmer\\Tenancy\\Project\\V1\\GPBMetadata\xea\x02!Ai::Stigmer::Tenancy::Project::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.tenancy.project.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.ai.stigmer.tenancy.project.v1B\tSpecProtoP\001\242\002\004ASTP\252\002\035Ai.Stigmer.Tenancy.Project.V1\312\002\035Ai\\Stigmer\\Tenancy\\Project\\V1\342\002)Ai\\Stigmer\\Tenancy\\Project\\V1\\GPBMetadata\352\002!Ai::Stigmer::Tenancy::Project::V1'
  _globals['_PROJECTSPEC']._serialized_start=117
  _globals['_PROJECTSPEC']._serialized_end=277
# @@protoc_insertion_point(module_scope)
