from ai.stigmer.iam.iampolicy.v1.rpcauthorization import io_pb2 as _io_pb2
from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
CONFIG_FIELD_NUMBER: _ClassVar[int]
config: _descriptor.FieldDescriptor
IS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
is_public: _descriptor.FieldDescriptor
IS_SKIP_AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
is_skip_authorization: _descriptor.FieldDescriptor
