# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/session/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/session/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.session.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2
from ai.stigmer.agentic.session.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)ai/stigmer/agentic/session/v1/query.proto\x12\x1d\x61i.stigmer.agentic.session.v1\x1a\'ai/stigmer/agentic/session/v1/api.proto\x1a&ai/stigmer/agentic/session/v1/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\x90\x03\n\x16SessionQueryController\x12\x85\x01\n\x03get\x12(.ai.stigmer.agentic.session.v1.SessionId\x1a&.ai.stigmer.agentic.session.v1.Session\",\xc2\xb8\x18(\x08\x03\x10*\"\x05value*\x1bunauthorized to get session\x12l\n\x04list\x12\x32.ai.stigmer.agentic.session.v1.ListSessionsRequest\x1a*.ai.stigmer.agentic.session.v1.SessionList\"\x04\xd0\xb8\x18\x01\x12z\n\x0blistByAgent\x12\x39.ai.stigmer.agentic.session.v1.ListSessionsByAgentRequest\x1a*.ai.stigmer.agentic.session.v1.SessionList\"\x04\xd0\xb8\x18\x01\x1a\x04\xa0\xff+*B\xc8\x01\n!com.ai.stigmer.agentic.session.v1B\nQueryProtoP\x01\xa2\x02\x04\x41SAS\xaa\x02\x1d\x41i.Stigmer.Agentic.Session.V1\xca\x02\x1d\x41i\\Stigmer\\Agentic\\Session\\V1\xe2\x02)Ai\\Stigmer\\Agentic\\Session\\V1\\GPBMetadata\xea\x02!Ai::Stigmer::Agentic::Session::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.session.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.ai.stigmer.agentic.session.v1B\nQueryProtoP\001\242\002\004ASAS\252\002\035Ai.Stigmer.Agentic.Session.V1\312\002\035Ai\\Stigmer\\Agentic\\Session\\V1\342\002)Ai\\Stigmer\\Agentic\\Session\\V1\\GPBMetadata\352\002!Ai::Stigmer::Agentic::Session::V1'
  _globals['_SESSIONQUERYCONTROLLER']._loaded_options = None
  _globals['_SESSIONQUERYCONTROLLER']._serialized_options = b'\240\377+*'
  _globals['_SESSIONQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_SESSIONQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\030(\010\003\020*\"\005value*\033unauthorized to get session'
  _globals['_SESSIONQUERYCONTROLLER'].methods_by_name['list']._loaded_options = None
  _globals['_SESSIONQUERYCONTROLLER'].methods_by_name['list']._serialized_options = b'\320\270\030\001'
  _globals['_SESSIONQUERYCONTROLLER'].methods_by_name['listByAgent']._loaded_options = None
  _globals['_SESSIONQUERYCONTROLLER'].methods_by_name['listByAgent']._serialized_options = b'\320\270\030\001'
  _globals['_SESSIONQUERYCONTROLLER']._serialized_start=283
  _globals['_SESSIONQUERYCONTROLLER']._serialized_end=683
# @@protoc_insertion_point(module_scope)
