# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowinstance/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowinstance/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ai/stigmer/agentic/workflowinstance/v1/spec.proto\x12&ai.stigmer.agentic.workflowinstance.v1\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x1b\x62uf/validate/validate.proto\"\xba\x02\n\x14WorkflowInstanceSpec\x12(\n\x0bworkflow_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\nworkflowId\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\xd5\x01\n\x10\x65nvironment_refs\x18\x03 \x03(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceBt\xbaHq\x92\x01n\"l\xba\x01i\n\x15\x65nvironment_refs.kind\x12?environment_refs must reference resources with kind=environment\x1a\x0fthis.kind == 52R\x0f\x65nvironmentRefsB\xf4\x01\n*com.ai.stigmer.agentic.workflowinstance.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02&Ai.Stigmer.Agentic.Workflowinstance.V1\xca\x02&Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\xe2\x02\x32\x41i\\Stigmer\\Agentic\\Workflowinstance\\V1\\GPBMetadata\xea\x02*Ai::Stigmer::Agentic::Workflowinstance::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowinstance.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.ai.stigmer.agentic.workflowinstance.v1B\tSpecProtoP\001\242\002\004ASAW\252\002&Ai.Stigmer.Agentic.Workflowinstance.V1\312\002&Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\342\0022Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\\GPBMetadata\352\002*Ai::Stigmer::Agentic::Workflowinstance::V1'
  _globals['_WORKFLOWINSTANCESPEC'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_WORKFLOWINSTANCESPEC'].fields_by_name['workflow_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_WORKFLOWINSTANCESPEC'].fields_by_name['environment_refs']._loaded_options = None
  _globals['_WORKFLOWINSTANCESPEC'].fields_by_name['environment_refs']._serialized_options = b'\272Hq\222\001n\"l\272\001i\n\025environment_refs.kind\022?environment_refs must reference resources with kind=environment\032\017this.kind == 52'
  _globals['_WORKFLOWINSTANCESPEC']._serialized_start=164
  _globals['_WORKFLOWINSTANCESPEC']._serialized_end=478
# @@protoc_insertion_point(module_scope)
