# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2
from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_enum__pb2
from ai.stigmer.agentic.agentexecution.v1 import usage_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_usage__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ai/stigmer/agentic/agentexecution/v1/io.proto\x12$ai.stigmer.agentic.agentexecution.v1\x1a.ai/stigmer/agentic/agentexecution/v1/api.proto\x1a/ai/stigmer/agentic/agentexecution/v1/enum.proto\x1a\x30\x61i/stigmer/agentic/agentexecution/v1/usage.proto\x1a\x1b\x62uf/validate/validate.proto\"0\n\x10\x41gentExecutionId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\")\n\tSessionId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\x85\x01\n\x12\x41gentExecutionList\x12\x1f\n\x0btotal_pages\x18\x01 \x01(\x05R\ntotalPages\x12N\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecutionR\x07\x65ntries\"\xb8\x01\n\x1aListAgentExecutionsRequest\x12\x1b\n\tpage_size\x18\x01 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\x12J\n\x05phase\x18\x03 \x01(\x0e\x32\x34.ai.stigmer.agentic.agentexecution.v1.ExecutionPhaseR\x05phase\x12\x12\n\x04tags\x18\x04 \x03(\tR\x04tags\"\x88\x01\n#ListAgentExecutionsBySessionRequest\x12%\n\nsession_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tsessionId\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xa9\x01\n\x1f\x41gentExecutionUpdateStatusInput\x12*\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x65xecutionId\x12Z\n\x06status\x18\x02 \x01(\x0b\x32:.ai.stigmer.agentic.agentexecution.v1.AgentExecutionStatusB\x06\xbaH\x03\xc8\x01\x01R\x06status\"\xeb\x01\n\x13SubmitApprovalInput\x12\x35\n\x12\x61gent_execution_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x10\x61gentExecutionId\x12)\n\x0ctool_call_id\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\ntoolCallId\x12X\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x34.ai.stigmer.agentic.agentexecution.v1.ApprovalActionB\n\xbaH\x07\x82\x01\x04\x10\x01 \x00R\x06\x61\x63tion\x12\x18\n\x07\x63omment\x18\x04 \x01(\tR\x07\x63omment\"o\n\x14\x41pprovalDecisionList\x12W\n\tdecisions\x18\x01 \x03(\x0b\x32\x39.ai.stigmer.agentic.agentexecution.v1.SubmitApprovalInputR\tdecisions\"L\n\x19\x43\x61ncelAgentExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"O\n\x1cTerminateAgentExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"5\n\x1aRecoverAgentExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\"K\n\x18PauseAgentExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"4\n\x19ResumeAgentExecutionInput\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x02id\"\x83\x01\n\x17UploadAttachmentRequest\x12#\n\x08\x66ilename\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x08\x66ilename\x12 \n\x07\x63ontent\x18\x02 \x01(\x0c\x42\x06\xbaH\x03\xc8\x01\x01R\x07\x63ontent\x12!\n\x0c\x63ontent_type\x18\x03 \x01(\tR\x0b\x63ontentType\";\n\x18UploadAttachmentResponse\x12\x1f\n\x0bstorage_key\x18\x01 \x01(\tR\nstorageKey\"u\n\x1dGetArtifactDownloadUrlRequest\x12*\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x65xecutionId\x12(\n\x0bstorage_key\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\nstorageKey\"b\n\x1eGetArtifactDownloadUrlResponse\x12!\n\x0c\x64ownload_url\x18\x01 \x01(\tR\x0b\x64ownloadUrl\x12\x1d\n\nexpires_at\x18\x02 \x01(\tR\texpiresAt\"\xad\x01\n\x19GetArtifactContentRequest\x12*\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x65xecutionId\x12(\n\x0bstorage_key\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\nstorageKey\x12\x1b\n\tmax_bytes\x18\x03 \x01(\x03R\x08maxBytes\x12\x1d\n\nentry_path\x18\x04 \x01(\tR\tentryPath\"\xa1\x01\n\x1aGetArtifactContentResponse\x12\x18\n\x07\x63ontent\x18\x01 \x01(\x0cR\x07\x63ontent\x12!\n\x0c\x63ontent_type\x18\x02 \x01(\tR\x0b\x63ontentType\x12(\n\x10total_size_bytes\x18\x03 \x01(\x03R\x0etotalSizeBytes\x12\x1c\n\ttruncated\x18\x04 \x01(\x08R\ttruncated\"D\n\x1aGetSessionUsageReportInput\x12&\n\nsession_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\tsessionId\"\x8d\x04\n\x1bGetSessionUsageReportOutput\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\'\n\x0f\x65xecution_count\x18\x02 \x01(\x05R\x0e\x65xecutionCount\x12S\n\x0btotal_usage\x18\x03 \x01(\x0b\x32\x32.ai.stigmer.agentic.agentexecution.v1.UsageMetricsR\ntotalUsage\x12[\n\nexecutions\x18\x04 \x03(\x0b\x32;.ai.stigmer.agentic.agentexecution.v1.ExecutionUsageSummaryR\nexecutions\x12Y\n\x0fmodel_breakdown\x18\x05 \x03(\x0b\x32\x30.ai.stigmer.agentic.agentexecution.v1.ModelUsageR\x0emodelBreakdown\x12?\n\x1ctotal_summarization_cost_usd\x18\x06 \x01(\x01R\x19totalSummarizationCostUsd\x12,\n\x12\x66irst_execution_at\x18\x07 \x01(\tR\x10\x66irstExecutionAt\x12*\n\x11last_execution_at\x18\x08 \x01(\tR\x0flastExecutionAt\"\xb0\x01\n\x18GetAgentUsageReportInput\x12\"\n\x08\x61gent_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x07\x61gentId\x12\x1b\n\tfrom_date\x18\x02 \x01(\tR\x08\x66romDate\x12\x17\n\x07to_date\x18\x03 \x01(\tR\x06toDate\x12\x1b\n\tpage_size\x18\x04 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x05 \x01(\tR\tpageToken\"\xfc\x03\n\x19GetAgentUsageReportOutput\x12\x19\n\x08\x61gent_id\x18\x01 \x01(\tR\x07\x61gentId\x12\x1d\n\nagent_name\x18\x02 \x01(\tR\tagentName\x12S\n\x0btotal_usage\x18\x03 \x01(\x0b\x32\x32.ai.stigmer.agentic.agentexecution.v1.UsageMetricsR\ntotalUsage\x12Y\n\x0fmodel_breakdown\x18\x04 \x03(\x0b\x32\x30.ai.stigmer.agentic.agentexecution.v1.ModelUsageR\x0emodelBreakdown\x12U\n\x08sessions\x18\x05 \x03(\x0b\x32\x39.ai.stigmer.agentic.agentexecution.v1.SessionUsageSummaryR\x08sessions\x12%\n\x0etotal_sessions\x18\x06 \x01(\x05R\rtotalSessions\x12)\n\x10total_executions\x18\x07 \x01(\x05R\x0ftotalExecutions\x12$\n\x0etotal_cost_usd\x18\x08 \x01(\x01R\x0ctotalCostUsd\x12&\n\x0fnext_page_token\x18\t \x01(\tR\rnextPageToken\"\x80\x01\n\x16GetOrgUsageReportInput\x12\x1e\n\x06org_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x05orgId\x12$\n\tfrom_date\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x08\x66romDate\x12 \n\x07to_date\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x06toDate\"\xe3\x03\n\x17GetOrgUsageReportOutput\x12\x15\n\x06org_id\x18\x01 \x01(\tR\x05orgId\x12!\n\x0ctotal_agents\x18\x02 \x01(\x05R\x0btotalAgents\x12%\n\x0etotal_sessions\x18\x03 \x01(\x05R\rtotalSessions\x12)\n\x10total_executions\x18\x04 \x01(\x05R\x0ftotalExecutions\x12$\n\x0etotal_cost_usd\x18\x05 \x01(\x01R\x0ctotalCostUsd\x12Y\n\x0fmodel_breakdown\x18\x06 \x03(\x0b\x32\x30.ai.stigmer.agentic.agentexecution.v1.ModelUsageR\x0emodelBreakdown\x12\x64\n\x12top_agents_by_cost\x18\x07 \x03(\x0b\x32\x37.ai.stigmer.agentic.agentexecution.v1.AgentUsageSummaryR\x0ftopAgentsByCost\x12U\n\x0b\x64\x61ily_costs\x18\x08 \x03(\x0b\x32\x34.ai.stigmer.agentic.agentexecution.v1.DailyCostEntryR\ndailyCosts\"\xc1\x03\n\x15\x45xecutionUsageSummary\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x1d\n\nstarted_at\x18\x02 \x01(\tR\tstartedAt\x12!\n\x0c\x63ompleted_at\x18\x03 \x01(\tR\x0b\x63ompletedAt\x12#\n\rprompt_tokens\x18\x04 \x01(\x05R\x0cpromptTokens\x12+\n\x11\x63ompletion_tokens\x18\x05 \x01(\x05R\x10\x63ompletionTokens\x12*\n\x11\x63\x61\x63he_read_tokens\x18\x06 \x01(\x05R\x0f\x63\x61\x63heReadTokens\x12,\n\x12\x65stimated_cost_usd\x18\x07 \x01(\x01R\x10\x65stimatedCostUsd\x12#\n\rprimary_model\x18\x08 \x01(\tR\x0cprimaryModel\x12&\n\x0fsub_agent_count\x18\t \x01(\x05R\rsubAgentCount\x12J\n\x05phase\x18\n \x01(\x0e\x32\x34.ai.stigmer.agentic.agentexecution.v1.ExecutionPhaseR\x05phase\"\x88\x02\n\x13SessionUsageSummary\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\'\n\x0f\x65xecution_count\x18\x02 \x01(\x05R\x0e\x65xecutionCount\x12!\n\x0ctotal_tokens\x18\x03 \x01(\x05R\x0btotalTokens\x12,\n\x12\x65stimated_cost_usd\x18\x04 \x01(\x01R\x10\x65stimatedCostUsd\x12,\n\x12\x66irst_execution_at\x18\x05 \x01(\tR\x10\x66irstExecutionAt\x12*\n\x11last_execution_at\x18\x06 \x01(\tR\x0flastExecutionAt\"\xc7\x01\n\x11\x41gentUsageSummary\x12\x19\n\x08\x61gent_id\x18\x01 \x01(\tR\x07\x61gentId\x12\x1d\n\nagent_name\x18\x02 \x01(\tR\tagentName\x12\'\n\x0f\x65xecution_count\x18\x03 \x01(\x05R\x0e\x65xecutionCount\x12!\n\x0ctotal_tokens\x18\x04 \x01(\x05R\x0btotalTokens\x12,\n\x12\x65stimated_cost_usd\x18\x05 \x01(\x01R\x10\x65stimatedCostUsd\"\x9e\x01\n\x0e\x44\x61ilyCostEntry\x12\x12\n\x04\x64\x61te\x18\x01 \x01(\tR\x04\x64\x61te\x12\'\n\x0f\x65xecution_count\x18\x02 \x01(\x05R\x0e\x65xecutionCount\x12!\n\x0ctotal_tokens\x18\x03 \x01(\x05R\x0btotalTokens\x12,\n\x12\x65stimated_cost_usd\x18\x04 \x01(\x01R\x10\x65stimatedCostUsdB\xe8\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\007IoProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_AGENTEXECUTIONID'].fields_by_name['value']._loaded_options = None
  _globals['_AGENTEXECUTIONID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SESSIONID'].fields_by_name['value']._loaded_options = None
  _globals['_SESSIONID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_LISTAGENTEXECUTIONSBYSESSIONREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_LISTAGENTEXECUTIONSBYSESSIONREQUEST'].fields_by_name['session_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_AGENTEXECUTIONUPDATESTATUSINPUT'].fields_by_name['execution_id']._loaded_options = None
  _globals['_AGENTEXECUTIONUPDATESTATUSINPUT'].fields_by_name['execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_AGENTEXECUTIONUPDATESTATUSINPUT'].fields_by_name['status']._loaded_options = None
  _globals['_AGENTEXECUTIONUPDATESTATUSINPUT'].fields_by_name['status']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SUBMITAPPROVALINPUT'].fields_by_name['agent_execution_id']._loaded_options = None
  _globals['_SUBMITAPPROVALINPUT'].fields_by_name['agent_execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SUBMITAPPROVALINPUT'].fields_by_name['tool_call_id']._loaded_options = None
  _globals['_SUBMITAPPROVALINPUT'].fields_by_name['tool_call_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SUBMITAPPROVALINPUT'].fields_by_name['action']._loaded_options = None
  _globals['_SUBMITAPPROVALINPUT'].fields_by_name['action']._serialized_options = b'\272H\007\202\001\004\020\001 \000'
  _globals['_CANCELAGENTEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_CANCELAGENTEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_TERMINATEAGENTEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_TERMINATEAGENTEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_RECOVERAGENTEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_RECOVERAGENTEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_PAUSEAGENTEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_PAUSEAGENTEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_RESUMEAGENTEXECUTIONINPUT'].fields_by_name['id']._loaded_options = None
  _globals['_RESUMEAGENTEXECUTIONINPUT'].fields_by_name['id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_UPLOADATTACHMENTREQUEST'].fields_by_name['filename']._loaded_options = None
  _globals['_UPLOADATTACHMENTREQUEST'].fields_by_name['filename']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_UPLOADATTACHMENTREQUEST'].fields_by_name['content']._loaded_options = None
  _globals['_UPLOADATTACHMENTREQUEST'].fields_by_name['content']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETARTIFACTDOWNLOADURLREQUEST'].fields_by_name['execution_id']._loaded_options = None
  _globals['_GETARTIFACTDOWNLOADURLREQUEST'].fields_by_name['execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETARTIFACTDOWNLOADURLREQUEST'].fields_by_name['storage_key']._loaded_options = None
  _globals['_GETARTIFACTDOWNLOADURLREQUEST'].fields_by_name['storage_key']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETARTIFACTCONTENTREQUEST'].fields_by_name['execution_id']._loaded_options = None
  _globals['_GETARTIFACTCONTENTREQUEST'].fields_by_name['execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETARTIFACTCONTENTREQUEST'].fields_by_name['storage_key']._loaded_options = None
  _globals['_GETARTIFACTCONTENTREQUEST'].fields_by_name['storage_key']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETSESSIONUSAGEREPORTINPUT'].fields_by_name['session_id']._loaded_options = None
  _globals['_GETSESSIONUSAGEREPORTINPUT'].fields_by_name['session_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETAGENTUSAGEREPORTINPUT'].fields_by_name['agent_id']._loaded_options = None
  _globals['_GETAGENTUSAGEREPORTINPUT'].fields_by_name['agent_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETORGUSAGEREPORTINPUT'].fields_by_name['org_id']._loaded_options = None
  _globals['_GETORGUSAGEREPORTINPUT'].fields_by_name['org_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETORGUSAGEREPORTINPUT'].fields_by_name['from_date']._loaded_options = None
  _globals['_GETORGUSAGEREPORTINPUT'].fields_by_name['from_date']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETORGUSAGEREPORTINPUT'].fields_by_name['to_date']._loaded_options = None
  _globals['_GETORGUSAGEREPORTINPUT'].fields_by_name['to_date']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_AGENTEXECUTIONID']._serialized_start=263
  _globals['_AGENTEXECUTIONID']._serialized_end=311
  _globals['_SESSIONID']._serialized_start=313
  _globals['_SESSIONID']._serialized_end=354
  _globals['_AGENTEXECUTIONLIST']._serialized_start=357
  _globals['_AGENTEXECUTIONLIST']._serialized_end=490
  _globals['_LISTAGENTEXECUTIONSREQUEST']._serialized_start=493
  _globals['_LISTAGENTEXECUTIONSREQUEST']._serialized_end=677
  _globals['_LISTAGENTEXECUTIONSBYSESSIONREQUEST']._serialized_start=680
  _globals['_LISTAGENTEXECUTIONSBYSESSIONREQUEST']._serialized_end=816
  _globals['_AGENTEXECUTIONUPDATESTATUSINPUT']._serialized_start=819
  _globals['_AGENTEXECUTIONUPDATESTATUSINPUT']._serialized_end=988
  _globals['_SUBMITAPPROVALINPUT']._serialized_start=991
  _globals['_SUBMITAPPROVALINPUT']._serialized_end=1226
  _globals['_APPROVALDECISIONLIST']._serialized_start=1228
  _globals['_APPROVALDECISIONLIST']._serialized_end=1339
  _globals['_CANCELAGENTEXECUTIONINPUT']._serialized_start=1341
  _globals['_CANCELAGENTEXECUTIONINPUT']._serialized_end=1417
  _globals['_TERMINATEAGENTEXECUTIONINPUT']._serialized_start=1419
  _globals['_TERMINATEAGENTEXECUTIONINPUT']._serialized_end=1498
  _globals['_RECOVERAGENTEXECUTIONINPUT']._serialized_start=1500
  _globals['_RECOVERAGENTEXECUTIONINPUT']._serialized_end=1553
  _globals['_PAUSEAGENTEXECUTIONINPUT']._serialized_start=1555
  _globals['_PAUSEAGENTEXECUTIONINPUT']._serialized_end=1630
  _globals['_RESUMEAGENTEXECUTIONINPUT']._serialized_start=1632
  _globals['_RESUMEAGENTEXECUTIONINPUT']._serialized_end=1684
  _globals['_UPLOADATTACHMENTREQUEST']._serialized_start=1687
  _globals['_UPLOADATTACHMENTREQUEST']._serialized_end=1818
  _globals['_UPLOADATTACHMENTRESPONSE']._serialized_start=1820
  _globals['_UPLOADATTACHMENTRESPONSE']._serialized_end=1879
  _globals['_GETARTIFACTDOWNLOADURLREQUEST']._serialized_start=1881
  _globals['_GETARTIFACTDOWNLOADURLREQUEST']._serialized_end=1998
  _globals['_GETARTIFACTDOWNLOADURLRESPONSE']._serialized_start=2000
  _globals['_GETARTIFACTDOWNLOADURLRESPONSE']._serialized_end=2098
  _globals['_GETARTIFACTCONTENTREQUEST']._serialized_start=2101
  _globals['_GETARTIFACTCONTENTREQUEST']._serialized_end=2274
  _globals['_GETARTIFACTCONTENTRESPONSE']._serialized_start=2277
  _globals['_GETARTIFACTCONTENTRESPONSE']._serialized_end=2438
  _globals['_GETSESSIONUSAGEREPORTINPUT']._serialized_start=2440
  _globals['_GETSESSIONUSAGEREPORTINPUT']._serialized_end=2508
  _globals['_GETSESSIONUSAGEREPORTOUTPUT']._serialized_start=2511
  _globals['_GETSESSIONUSAGEREPORTOUTPUT']._serialized_end=3036
  _globals['_GETAGENTUSAGEREPORTINPUT']._serialized_start=3039
  _globals['_GETAGENTUSAGEREPORTINPUT']._serialized_end=3215
  _globals['_GETAGENTUSAGEREPORTOUTPUT']._serialized_start=3218
  _globals['_GETAGENTUSAGEREPORTOUTPUT']._serialized_end=3726
  _globals['_GETORGUSAGEREPORTINPUT']._serialized_start=3729
  _globals['_GETORGUSAGEREPORTINPUT']._serialized_end=3857
  _globals['_GETORGUSAGEREPORTOUTPUT']._serialized_start=3860
  _globals['_GETORGUSAGEREPORTOUTPUT']._serialized_end=4343
  _globals['_EXECUTIONUSAGESUMMARY']._serialized_start=4346
  _globals['_EXECUTIONUSAGESUMMARY']._serialized_end=4795
  _globals['_SESSIONUSAGESUMMARY']._serialized_start=4798
  _globals['_SESSIONUSAGESUMMARY']._serialized_end=5062
  _globals['_AGENTUSAGESUMMARY']._serialized_start=5065
  _globals['_AGENTUSAGESUMMARY']._serialized_end=5264
  _globals['_DAILYCOSTENTRY']._serialized_start=5267
  _globals['_DAILYCOSTENTRY']._serialized_end=5425
# @@protoc_insertion_point(module_scope)
