# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/apikey/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/apikey/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import field_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_field__options__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ai/stigmer/iam/apikey/v1/spec.proto\x12\x18\x61i.stigmer.iam.apikey.v1\x1a\x32\x61i/stigmer/commons/apiresource/field_options.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x01\n\nApiKeySpec\x12\x1f\n\x08key_hash\x18\x01 \x01(\tB\x04\xc8\x85,\x01R\x07keyHash\x12&\n\x0b\x66ingerprint\x18\x02 \x01(\tB\x04\xc8\x85,\x01R\x0b\x66ingerprint\x12\x39\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12#\n\rnever_expires\x18\x04 \x01(\x08R\x0cneverExpiresB\xae\x01\n\x1c\x63om.ai.stigmer.iam.apikey.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SIA\xaa\x02\x18\x41i.Stigmer.Iam.Apikey.V1\xca\x02\x18\x41i\\Stigmer\\Iam\\Apikey\\V1\xe2\x02$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\xea\x02\x1c\x41i::Stigmer::Iam::Apikey::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.apikey.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.ai.stigmer.iam.apikey.v1B\tSpecProtoP\001\242\002\004ASIA\252\002\030Ai.Stigmer.Iam.Apikey.V1\312\002\030Ai\\Stigmer\\Iam\\Apikey\\V1\342\002$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\352\002\034Ai::Stigmer::Iam::Apikey::V1'
  _globals['_APIKEYSPEC'].fields_by_name['key_hash']._loaded_options = None
  _globals['_APIKEYSPEC'].fields_by_name['key_hash']._serialized_options = b'\310\205,\001'
  _globals['_APIKEYSPEC'].fields_by_name['fingerprint']._loaded_options = None
  _globals['_APIKEYSPEC'].fields_by_name['fingerprint']._serialized_options = b'\310\205,\001'
  _globals['_APIKEYSPEC']._serialized_start=151
  _globals['_APIKEYSPEC']._serialized_end=332
# @@protoc_insertion_point(module_scope)
