# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/skill/v1/synth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/skill/v1/synth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ai/stigmer/agentic/skill/v1/synth.proto\x12\x1b\x61i.stigmer.agentic.skill.v1\"\x9d\x01\n\nSkillSynth\x12=\n\x05local\x18\x01 \x01(\x0b\x32%.ai.stigmer.agentic.skill.v1.LocalDirH\x00R\x05local\x12\x34\n\x03git\x18\x02 \x01(\x0b\x32 .ai.stigmer.agentic.skill.v1.GitH\x00R\x03git\x12\x10\n\x03tag\x18\x03 \x01(\tR\x03tagB\x08\n\x06source\"\x1e\n\x08LocalDir\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\"A\n\x03Git\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\x12\x10\n\x03ref\x18\x02 \x01(\tR\x03ref\x12\x16\n\x06subdir\x18\x03 \x01(\tR\x06subdirB\xbe\x01\n\x1f\x63om.ai.stigmer.agentic.skill.v1B\nSynthProtoP\x01\xa2\x02\x04\x41SAS\xaa\x02\x1b\x41i.Stigmer.Agentic.Skill.V1\xca\x02\x1b\x41i\\Stigmer\\Agentic\\Skill\\V1\xe2\x02\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Agentic::Skill::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.skill.v1.synth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.agentic.skill.v1B\nSynthProtoP\001\242\002\004ASAS\252\002\033Ai.Stigmer.Agentic.Skill.V1\312\002\033Ai\\Stigmer\\Agentic\\Skill\\V1\342\002\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Agentic::Skill::V1'
  _globals['_SKILLSYNTH']._serialized_start=73
  _globals['_SKILLSYNTH']._serialized_end=230
  _globals['_LOCALDIR']._serialized_start=232
  _globals['_LOCALDIR']._serialized_end=262
  _globals['_GIT']._serialized_start=264
  _globals['_GIT']._serialized_end=329
# @@protoc_insertion_point(module_scope)
