# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/apiresource/apiresourcekind/api_resource_kind.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/apiresource/apiresourcekind/api_resource_kind.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_group_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_apiresourcekind_dot_api__resource__group__pb2
from ai.stigmer.commons.apiresource.apiresourcekind import authorization_config_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_apiresourcekind_dot_authorization__config__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFai/stigmer/commons/apiresource/apiresourcekind/api_resource_kind.proto\x12.ai.stigmer.commons.apiresource.apiresourcekind\x1aGai/stigmer/commons/apiresource/apiresourcekind/api_resource_group.proto\x1aIai/stigmer/commons/apiresource/apiresourcekind/authorization_config.proto\x1a google/protobuf/descriptor.proto\"\xad\x04\n\x13\x41piResourceKindMeta\x12V\n\x05group\x18\x01 \x01(\x0e\x32@.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceGroupR\x05group\x12\\\n\x07version\x18\x02 \x01(\x0e\x32\x42.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceVersionR\x07version\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12!\n\x0c\x64isplay_name\x18\x04 \x01(\tR\x0b\x64isplayName\x12\x1b\n\tid_prefix\x18\x05 \x01(\tR\x08idPrefix\x12!\n\x0cis_versioned\x18\x06 \x01(\x08R\x0bisVersioned\x12,\n\x12not_search_indexed\x18\x07 \x01(\x08R\x10notSearchIndexed\x12P\n\x04tier\x18\x08 \x01(\x0e\x32<.ai.stigmer.commons.apiresource.apiresourcekind.ResourceTierR\x04tier\x12i\n\rauthorization\x18\t \x01(\x0b\x32\x43.ai.stigmer.commons.apiresource.apiresourcekind.AuthorizationConfigR\rauthorization*B\n\x12\x41piResourceVersion\x12$\n api_resource_version_unspecified\x10\x00\x12\x06\n\x02v1\x10\x01*N\n\x0cResourceTier\x12\x1d\n\x19resource_tier_unspecified\x10\x00\x12\x0f\n\x0bopen_source\x10\x01\x12\x0e\n\ncloud_only\x10\x02*A\n\x0fPlatformIdValue\x12!\n\x1dplatform_id_value_unspecified\x10\x00\x12\x0b\n\x07stigmer\x10\x01*\xb8\x0b\n\x0f\x41piResourceKind\x12\x1d\n\x19\x61pi_resource_kind_unknown\x10\x00\x12[\n\x14\x61pi_resource_version\x10\x01\x1a\x41\xaa\xff+=\x08\x01\x10\x01\x1a\x12\x41piResourceVersion\"\x14\x41PI Resource Version*\x03ver8\x01@\x02J\x04\x08\x05\x10\x04\x12?\n\niam_policy\x10\n\x1a/\xaa\xff++\x08\x02\x10\x01\x1a\tIamPolicy\"\nIAM Policy*\x04iamp8\x01@\x02J\x04\x08\x02\x10\x01\x12N\n\x10identity_account\x10\x0b\x1a\x38\xaa\xff+4\x08\x02\x10\x01\x1a\x0fIdentityAccount\"\x10Identity Account*\x03ida@\x02J\x04\x08\x04\x10\x03\x12\x35\n\x07\x61pi_key\x10\x0c\x1a(\xaa\xff+$\x08\x02\x10\x01\x1a\x06\x41piKey\"\x07\x41PI Key*\x03key8\x01@\x02J\x04\x08\x04\x10\x01\x12S\n\x11identity_provider\x10\x15\x1a<\xaa\xff+8\x08\x02\x10\x01\x1a\x10IdentityProvider\"\x11Identity Provider*\x03idp8\x01@\x02J\x04\x08\x02\x10\x01\x12\x43\n\x0corganization\x10\x1e\x1a\x31\xaa\xff+-\x08\x03\x10\x01\x1a\x0cOrganization\"\x0cOrganization*\x03org@\x01J\x04\x08\x04\x10\x01\x12\x39\n\x08platform\x10\x1f\x1a+\xaa\xff+\'\x08\x03\x10\x01\x1a\x08Platform\"\x08Platform*\x03plt8\x01@\x02J\x04\x08\x05\x10\x04\x12\x32\n\x05\x61gent\x10(\x1a\'\xaa\xff+#\x08\x01\x10\x01\x1a\x05\x41gent\"\x05\x41gent*\x03\x61gt@\x01J\x08\x08\x02\x10\x01*\x02\x08\x01\x12k\n\x0f\x61gent_execution\x10)\x1aV\xaa\xff+R\x08\x01\x10\x01\x1a\x0e\x41gentExecution\"\x0f\x41gent Execution*\x03\x61\x65x@\x01J$\x08\x03\x10\x02\x1a\x1e\n\x07session\x12\x07session\x1a\nsession_id\x12\x34\n\x07session\x10*\x1a\'\xaa\xff+#\x08\x01\x10\x01\x1a\x07Session\"\x07Session*\x03ses@\x01J\x04\x08\x02\x10\x01\x12\x34\n\x05skill\x10+\x1a)\xaa\xff+%\x08\x01\x10\x01\x1a\x05Skill\"\x05Skill*\x03skl0\x01@\x01J\x08\x08\x02\x10\x01*\x02\x08\x01\x12@\n\nmcp_server\x10,\x1a\x30\xaa\xff+,\x08\x01\x10\x01\x1a\tMcpServer\"\nMCP Server*\x03mcp@\x01J\x08\x08\x02\x10\x01*\x02\x08\x01\x12\x66\n\x0e\x61gent_instance\x10-\x1aR\xaa\xff+N\x08\x01\x10\x01\x1a\rAgentInstance\"\x0e\x41gent Instance*\x03\x61in@\x01J\"\x08\x02\x10\x01\"\x18\n\x05\x61gent\x12\x05\x61gent\x1a\x08\x61gent_id*\x02\x08\x01\x12;\n\x08workflow\x10\x32\x1a-\xaa\xff+)\x08\x01\x10\x01\x1a\x08Workflow\"\x08Workflow*\x03wfl@\x01J\x08\x08\x02\x10\x01*\x02\x08\x01\x12t\n\x11workflow_instance\x10\x33\x1a]\xaa\xff+Y\x08\x01\x10\x01\x1a\x10WorkflowInstance\"\x11Workflow Instance*\x03win@\x01J\'\x08\x02\x10\x01\"!\n\x08workflow\x12\x08workflow\x1a\x0bworkflow_id\x12T\n\x12workflow_execution\x10\x34\x1a<\xaa\xff+8\x08\x01\x10\x01\x1a\x11WorkflowExecution\"\x12Workflow Execution*\x03wex@\x01J\x04\x08\x02\x10\x01\x12\x42\n\x0b\x65nvironment\x10\x35\x1a\x31\xaa\xff+-\x08\x01\x10\x01\x1a\x0b\x45nvironment\"\x0b\x45nvironment*\x03\x65nv@\x01J\x06\x08\x02\x10\x01\x30\x01\x12R\n\x11\x65xecution_context\x10\x36\x1a;\xaa\xff+7\x08\x01\x10\x01\x1a\x10\x45xecutionContext\"\x11\x45xecution Context*\x04\x65xec@\x01J\x04\x08\x05\x10\x04\x12\x34\n\x07project\x10<\x1a\'\xaa\xff+#\x08\x03\x10\x01\x1a\x07Project\"\x07Project*\x03prj@\x01J\x04\x08\x02\x10\x01:\x85\x01\n\tkind_meta\x12!.google.protobuf.EnumValueOptions\x18\xf5\xbf\x05 \x01(\x0b\x32\x43.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceKindMetaR\x08kindMetaB\xa8\x02\n2com.ai.stigmer.commons.apiresource.apiresourcekindB\x14\x41piResourceKindProtoP\x01\xa2\x02\x05\x41SCAA\xaa\x02.Ai.Stigmer.Commons.Apiresource.Apiresourcekind\xca\x02.Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\xe2\x02:Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\\GPBMetadata\xea\x02\x32\x41i::Stigmer::Commons::Apiresource::Apiresourcekindb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.apiresource.apiresourcekind.api_resource_kind_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n2com.ai.stigmer.commons.apiresource.apiresourcekindB\024ApiResourceKindProtoP\001\242\002\005ASCAA\252\002.Ai.Stigmer.Commons.Apiresource.Apiresourcekind\312\002.Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\342\002:Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\\GPBMetadata\352\0022Ai::Stigmer::Commons::Apiresource::Apiresourcekind'
  _globals['_APIRESOURCEKIND'].values_by_name["api_resource_version"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["api_resource_version"]._serialized_options = b'\252\377+=\010\001\020\001\032\022ApiResourceVersion\"\024API Resource Version*\003ver8\001@\002J\004\010\005\020\004'
  _globals['_APIRESOURCEKIND'].values_by_name["iam_policy"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["iam_policy"]._serialized_options = b'\252\377++\010\002\020\001\032\tIamPolicy\"\nIAM Policy*\004iamp8\001@\002J\004\010\002\020\001'
  _globals['_APIRESOURCEKIND'].values_by_name["identity_account"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["identity_account"]._serialized_options = b'\252\377+4\010\002\020\001\032\017IdentityAccount\"\020Identity Account*\003ida@\002J\004\010\004\020\003'
  _globals['_APIRESOURCEKIND'].values_by_name["api_key"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["api_key"]._serialized_options = b'\252\377+$\010\002\020\001\032\006ApiKey\"\007API Key*\003key8\001@\002J\004\010\004\020\001'
  _globals['_APIRESOURCEKIND'].values_by_name["identity_provider"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["identity_provider"]._serialized_options = b'\252\377+8\010\002\020\001\032\020IdentityProvider\"\021Identity Provider*\003idp8\001@\002J\004\010\002\020\001'
  _globals['_APIRESOURCEKIND'].values_by_name["organization"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["organization"]._serialized_options = b'\252\377+-\010\003\020\001\032\014Organization\"\014Organization*\003org@\001J\004\010\004\020\001'
  _globals['_APIRESOURCEKIND'].values_by_name["platform"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["platform"]._serialized_options = b'\252\377+\'\010\003\020\001\032\010Platform\"\010Platform*\003plt8\001@\002J\004\010\005\020\004'
  _globals['_APIRESOURCEKIND'].values_by_name["agent"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["agent"]._serialized_options = b'\252\377+#\010\001\020\001\032\005Agent\"\005Agent*\003agt@\001J\010\010\002\020\001*\002\010\001'
  _globals['_APIRESOURCEKIND'].values_by_name["agent_execution"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["agent_execution"]._serialized_options = b'\252\377+R\010\001\020\001\032\016AgentExecution\"\017Agent Execution*\003aex@\001J$\010\003\020\002\032\036\n\007session\022\007session\032\nsession_id'
  _globals['_APIRESOURCEKIND'].values_by_name["session"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["session"]._serialized_options = b'\252\377+#\010\001\020\001\032\007Session\"\007Session*\003ses@\001J\004\010\002\020\001'
  _globals['_APIRESOURCEKIND'].values_by_name["skill"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["skill"]._serialized_options = b'\252\377+%\010\001\020\001\032\005Skill\"\005Skill*\003skl0\001@\001J\010\010\002\020\001*\002\010\001'
  _globals['_APIRESOURCEKIND'].values_by_name["mcp_server"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["mcp_server"]._serialized_options = b'\252\377+,\010\001\020\001\032\tMcpServer\"\nMCP Server*\003mcp@\001J\010\010\002\020\001*\002\010\001'
  _globals['_APIRESOURCEKIND'].values_by_name["agent_instance"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["agent_instance"]._serialized_options = b'\252\377+N\010\001\020\001\032\rAgentInstance\"\016Agent Instance*\003ain@\001J\"\010\002\020\001\"\030\n\005agent\022\005agent\032\010agent_id*\002\010\001'
  _globals['_APIRESOURCEKIND'].values_by_name["workflow"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["workflow"]._serialized_options = b'\252\377+)\010\001\020\001\032\010Workflow\"\010Workflow*\003wfl@\001J\010\010\002\020\001*\002\010\001'
  _globals['_APIRESOURCEKIND'].values_by_name["workflow_instance"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["workflow_instance"]._serialized_options = b'\252\377+Y\010\001\020\001\032\020WorkflowInstance\"\021Workflow Instance*\003win@\001J\'\010\002\020\001\"!\n\010workflow\022\010workflow\032\013workflow_id'
  _globals['_APIRESOURCEKIND'].values_by_name["workflow_execution"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["workflow_execution"]._serialized_options = b'\252\377+8\010\001\020\001\032\021WorkflowExecution\"\022Workflow Execution*\003wex@\001J\004\010\002\020\001'
  _globals['_APIRESOURCEKIND'].values_by_name["environment"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["environment"]._serialized_options = b'\252\377+-\010\001\020\001\032\013Environment\"\013Environment*\003env@\001J\006\010\002\020\0010\001'
  _globals['_APIRESOURCEKIND'].values_by_name["execution_context"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["execution_context"]._serialized_options = b'\252\377+7\010\001\020\001\032\020ExecutionContext\"\021Execution Context*\004exec@\001J\004\010\005\020\004'
  _globals['_APIRESOURCEKIND'].values_by_name["project"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["project"]._serialized_options = b'\252\377+#\010\003\020\001\032\007Project\"\007Project*\003prj@\001J\004\010\002\020\001'
  _globals['_APIRESOURCEVERSION']._serialized_start=864
  _globals['_APIRESOURCEVERSION']._serialized_end=930
  _globals['_RESOURCETIER']._serialized_start=932
  _globals['_RESOURCETIER']._serialized_end=1010
  _globals['_PLATFORMIDVALUE']._serialized_start=1012
  _globals['_PLATFORMIDVALUE']._serialized_end=1077
  _globals['_APIRESOURCEKIND']._serialized_start=1080
  _globals['_APIRESOURCEKIND']._serialized_end=2544
  _globals['_APIRESOURCEKINDMETA']._serialized_start=305
  _globals['_APIRESOURCEKINDMETA']._serialized_end=862
# @@protoc_insertion_point(module_scope)
