# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2
from ai.stigmer.agentic.agentexecution.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2ai/stigmer/agentic/agentexecution/v1/command.proto\x12$ai.stigmer.agentic.agentexecution.v1\x1a.ai/stigmer/agentic/agentexecution/v1/api.proto\x1a-ai/stigmer/agentic/agentexecution/v1/io.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xe4\x0f\n\x1f\x41gentExecutionCommandController\x12z\n\x06\x63reate\x12\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"\x04\xd0\xb8\x18\x01\x12\xb3\x01\n\x06update\x12\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"=\xc2\xb8\x18\x39\x08\x04\x10)\"\x0bmetadata.id*&unauthorized to update agent execution\x12\xcd\x01\n\x0cupdateStatus\x12\x45.ai.stigmer.agentic.agentexecution.v1.AgentExecutionUpdateStatusInput\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"@\xc2\xb8\x18<\x08\x1f\x10\x1f*-unauthorized to update agent execution status2\x07stigmer\x12\xa6\x01\n\x06\x64\x65lete\x12-.ai.stigmer.commons.apiresource.ApiResourceId\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"7\xc2\xb8\x18\x33\x08\x04\x10)\"\x05value*&unauthorized to delete agent execution\x12\xd4\x01\n\x0esubmitApproval\x12\x39.ai.stigmer.agentic.agentexecution.v1.SubmitApprovalInput\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"Q\xc2\xb8\x18M\x08\x04\x10)\"\x12\x61gent_execution_id*3unauthorized to submit approval for agent execution\x12\xb5\x01\n\x06\x63\x61ncel\x12?.ai.stigmer.agentic.agentexecution.v1.CancelAgentExecutionInput\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"4\xc2\xb8\x18\x30\x08\x04\x10)\"\x02id*&unauthorized to cancel agent execution\x12\xbe\x01\n\tterminate\x12\x42.ai.stigmer.agentic.agentexecution.v1.TerminateAgentExecutionInput\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"7\xc2\xb8\x18\x33\x08\x04\x10)\"\x02id*)unauthorized to terminate agent execution\x12\xb8\x01\n\x07recover\x12@.ai.stigmer.agentic.agentexecution.v1.RecoverAgentExecutionInput\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"5\xc2\xb8\x18\x31\x08\x04\x10)\"\x02id*\'unauthorized to recover agent execution\x12\xb2\x01\n\x05pause\x12>.ai.stigmer.agentic.agentexecution.v1.PauseAgentExecutionInput\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"3\xc2\xb8\x18/\x08\x04\x10)\"\x02id*%unauthorized to pause agent execution\x12\xb5\x01\n\x06resume\x12?.ai.stigmer.agentic.agentexecution.v1.ResumeAgentExecutionInput\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"4\xc2\xb8\x18\x30\x08\x04\x10)\"\x02id*&unauthorized to resume agent execution\x12\x97\x01\n\x10uploadAttachment\x12=.ai.stigmer.agentic.agentexecution.v1.UploadAttachmentRequest\x1a>.ai.stigmer.agentic.agentexecution.v1.UploadAttachmentResponse\"\x04\xd0\xb8\x18\x01\x1a\x04\xa0\xff+)B\xed\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\014CommandProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER']._serialized_options = b'\240\377+)'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['update']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['update']._serialized_options = b'\302\270\0309\010\004\020)\"\013metadata.id*&unauthorized to update agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['updateStatus']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['updateStatus']._serialized_options = b'\302\270\030<\010\037\020\037*-unauthorized to update agent execution status2\007stigmer'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\0303\010\004\020)\"\005value*&unauthorized to delete agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['submitApproval']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['submitApproval']._serialized_options = b'\302\270\030M\010\004\020)\"\022agent_execution_id*3unauthorized to submit approval for agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['cancel']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['cancel']._serialized_options = b'\302\270\0300\010\004\020)\"\002id*&unauthorized to cancel agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['terminate']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['terminate']._serialized_options = b'\302\270\0303\010\004\020)\"\002id*)unauthorized to terminate agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['recover']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['recover']._serialized_options = b'\302\270\0301\010\004\020)\"\002id*\'unauthorized to recover agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['pause']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['pause']._serialized_options = b'\302\270\030/\010\004\020)\"\002id*%unauthorized to pause agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['resume']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['resume']._serialized_options = b'\302\270\0300\010\004\020)\"\002id*&unauthorized to resume agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['uploadAttachment']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['uploadAttachment']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER']._serialized_start=354
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER']._serialized_end=2374
# @@protoc_insertion_point(module_scope)
