# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agent/v1/api.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agent/v1/api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agent.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_spec__pb2
from ai.stigmer.agentic.agent.v1 import status_pb2 as ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_status__pb2
from ai.stigmer.commons.apiresource import metadata_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_metadata__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ai/stigmer/agentic/agent/v1/api.proto\x12\x1b\x61i.stigmer.agentic.agent.v1\x1a&ai/stigmer/agentic/agent/v1/spec.proto\x1a(ai/stigmer/agentic/agent/v1/status.proto\x1a-ai/stigmer/commons/apiresource/metadata.proto\x1a\x1b\x62uf/validate/validate.proto\"\xbf\x02\n\x05\x41gent\x12=\n\x0b\x61pi_version\x18\x01 \x01(\tB\x1c\xbaH\x19r\x17\n\x15\x61gentic.stigmer.ai/v1R\napiVersion\x12 \n\x04kind\x18\x02 \x01(\tB\x0c\xbaH\tr\x07\n\x05\x41gentR\x04kind\x12W\n\x08metadata\x18\x03 \x01(\x0b\x32\x33.ai.stigmer.commons.apiresource.ApiResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12:\n\x04spec\x18\x04 \x01(\x0b\x32&.ai.stigmer.agentic.agent.v1.AgentSpecR\x04spec\x12@\n\x06status\x18\x05 \x01(\x0b\x32(.ai.stigmer.agentic.agent.v1.AgentStatusR\x06statusB\xbc\x01\n\x1f\x63om.ai.stigmer.agentic.agent.v1B\x08\x41piProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02\x1b\x41i.Stigmer.Agentic.Agent.V1\xca\x02\x1b\x41i\\Stigmer\\Agentic\\Agent\\V1\xe2\x02\'Ai\\Stigmer\\Agentic\\Agent\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Agentic::Agent::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agent.v1.api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.agentic.agent.v1B\010ApiProtoP\001\242\002\004ASAA\252\002\033Ai.Stigmer.Agentic.Agent.V1\312\002\033Ai\\Stigmer\\Agentic\\Agent\\V1\342\002\'Ai\\Stigmer\\Agentic\\Agent\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Agentic::Agent::V1'
  _globals['_AGENT'].fields_by_name['api_version']._loaded_options = None
  _globals['_AGENT'].fields_by_name['api_version']._serialized_options = b'\272H\031r\027\n\025agentic.stigmer.ai/v1'
  _globals['_AGENT'].fields_by_name['kind']._loaded_options = None
  _globals['_AGENT'].fields_by_name['kind']._serialized_options = b'\272H\tr\007\n\005Agent'
  _globals['_AGENT'].fields_by_name['metadata']._loaded_options = None
  _globals['_AGENT'].fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _globals['_AGENT']._serialized_start=229
  _globals['_AGENT']._serialized_end=548
# @@protoc_insertion_point(module_scope)
