# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2
from ai.stigmer.agentic.agentexecution.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ai/stigmer/agentic/agentexecution/v1/query.proto\x12$ai.stigmer.agentic.agentexecution.v1\x1a.ai/stigmer/agentic/agentexecution/v1/api.proto\x1a-ai/stigmer/agentic/agentexecution/v1/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xf7\x0c\n\x1d\x41gentExecutionQueryController\x12\xa9\x01\n\x03get\x12\x36.ai.stigmer.agentic.agentexecution.v1.AgentExecutionId\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"4\xc2\xb8\x18\x30\x08\x03\x10)\"\x05value*#unauthorized to get agent execution\x12\x88\x01\n\x04list\x12@.ai.stigmer.agentic.agentexecution.v1.ListAgentExecutionsRequest\x1a\x38.ai.stigmer.agentic.agentexecution.v1.AgentExecutionList\"\x04\xd0\xb8\x18\x01\x12\x9a\x01\n\rlistBySession\x12I.ai.stigmer.agentic.agentexecution.v1.ListAgentExecutionsBySessionRequest\x1a\x38.ai.stigmer.agentic.agentexecution.v1.AgentExecutionList\"\x04\xd0\xb8\x18\x01\x12\xba\x01\n\tsubscribe\x12\x36.ai.stigmer.agentic.agentexecution.v1.AgentExecutionId\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"=\xc2\xb8\x18\x39\x08\x03\x10)\"\x05value*,unauthorized to subscribe to agent execution0\x01\x12\xf3\x01\n\x16getArtifactDownloadUrl\x12\x43.ai.stigmer.agentic.agentexecution.v1.GetArtifactDownloadUrlRequest\x1a\x44.ai.stigmer.agentic.agentexecution.v1.GetArtifactDownloadUrlResponse\"N\xc2\xb8\x18J\x08\x03\x10)\"\x0c\x65xecution_id*6unauthorized to download artifact from agent execution\x12\xeb\x01\n\x12getArtifactContent\x12?.ai.stigmer.agentic.agentexecution.v1.GetArtifactContentRequest\x1a@.ai.stigmer.agentic.agentexecution.v1.GetArtifactContentResponse\"R\xc2\xb8\x18N\x08\x03\x10)\"\x0c\x65xecution_id*:unauthorized to read artifact content from agent execution\x12\xa2\x01\n\x15getSessionUsageReport\x12@.ai.stigmer.agentic.agentexecution.v1.GetSessionUsageReportInput\x1a\x41.ai.stigmer.agentic.agentexecution.v1.GetSessionUsageReportOutput\"\x04\xd0\xb8\x18\x01\x12\x9c\x01\n\x13getAgentUsageReport\x12>.ai.stigmer.agentic.agentexecution.v1.GetAgentUsageReportInput\x1a?.ai.stigmer.agentic.agentexecution.v1.GetAgentUsageReportOutput\"\x04\xd0\xb8\x18\x01\x12\x96\x01\n\x11getOrgUsageReport\x12<.ai.stigmer.agentic.agentexecution.v1.GetOrgUsageReportInput\x1a=.ai.stigmer.agentic.agentexecution.v1.GetOrgUsageReportOutput\"\x04\xd0\xb8\x18\x01\x1a\x04\xa0\xff+)B\xeb\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\nQueryProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\nQueryProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER']._serialized_options = b'\240\377+)'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\0300\010\003\020)\"\005value*#unauthorized to get agent execution'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['list']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['list']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['listBySession']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['listBySession']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['subscribe']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['subscribe']._serialized_options = b'\302\270\0309\010\003\020)\"\005value*,unauthorized to subscribe to agent execution'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getArtifactDownloadUrl']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getArtifactDownloadUrl']._serialized_options = b'\302\270\030J\010\003\020)\"\014execution_id*6unauthorized to download artifact from agent execution'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getArtifactContent']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getArtifactContent']._serialized_options = b'\302\270\030N\010\003\020)\"\014execution_id*:unauthorized to read artifact content from agent execution'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getSessionUsageReport']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getSessionUsageReport']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getAgentUsageReport']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getAgentUsageReport']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getOrgUsageReport']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getOrgUsageReport']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER']._serialized_start=311
  _globals['_AGENTEXECUTIONQUERYCONTROLLER']._serialized_end=1966
# @@protoc_insertion_point(module_scope)
