# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/serverless/validation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/serverless/validation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:ai/stigmer/agentic/workflow/v1/serverless/validation.proto\x12)ai.stigmer.agentic.workflow.v1.serverless\x1a\x1fgoogle/protobuf/timestamp.proto\"\xad\x02\n\x1cServerlessWorkflowValidation\x12P\n\x05state\x18\x01 \x01(\x0e\x32:.ai.stigmer.agentic.workflow.v1.serverless.ValidationStateR\x05state\x12\x12\n\x04yaml\x18\x02 \x01(\tR\x04yaml\x12\x16\n\x06\x65rrors\x18\x03 \x03(\tR\x06\x65rrors\x12\x1a\n\x08warnings\x18\x04 \x03(\tR\x08warnings\x12=\n\x0cvalidated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0bvalidatedAt\x12\x34\n\x16validation_workflow_id\x18\x06 \x01(\tR\x14validationWorkflowId*d\n\x0fValidationState\x12 \n\x1cVALIDATION_STATE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\t\n\x05VALID\x10\x02\x12\x0b\n\x07INVALID\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42\x8c\x02\n-com.ai.stigmer.agentic.workflow.v1.serverlessB\x0fValidationProtoP\x01\xa2\x02\x06\x41SAWVS\xaa\x02)Ai.Stigmer.Agentic.Workflow.V1.Serverless\xca\x02)Ai\\Stigmer\\Agentic\\Workflow\\V1\\Serverless\xe2\x02\x35\x41i\\Stigmer\\Agentic\\Workflow\\V1\\Serverless\\GPBMetadata\xea\x02.Ai::Stigmer::Agentic::Workflow::V1::Serverlessb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.serverless.validation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-com.ai.stigmer.agentic.workflow.v1.serverlessB\017ValidationProtoP\001\242\002\006ASAWVS\252\002)Ai.Stigmer.Agentic.Workflow.V1.Serverless\312\002)Ai\\Stigmer\\Agentic\\Workflow\\V1\\Serverless\342\0025Ai\\Stigmer\\Agentic\\Workflow\\V1\\Serverless\\GPBMetadata\352\002.Ai::Stigmer::Agentic::Workflow::V1::Serverless'
  _globals['_VALIDATIONSTATE']._serialized_start=442
  _globals['_VALIDATIONSTATE']._serialized_end=542
  _globals['_SERVERLESSWORKFLOWVALIDATION']._serialized_start=139
  _globals['_SERVERLESSWORKFLOWVALIDATION']._serialized_end=440
# @@protoc_insertion_point(module_scope)
