# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentinstance/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentinstance/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentinstance.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2
from ai.stigmer.commons.rpc import pagination_pb2 as ai_dot_stigmer_dot_commons_dot_rpc_dot_pagination__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ai/stigmer/agentic/agentinstance/v1/io.proto\x12#ai.stigmer.agentic.agentinstance.v1\x1a-ai/stigmer/agentic/agentinstance/v1/api.proto\x1a\'ai/stigmer/commons/rpc/pagination.proto\x1a\x1b\x62uf/validate/validate.proto\"/\n\x0f\x41gentInstanceId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\x83\x01\n\x1fGetAgentInstancesByAgentRequest\x12!\n\x08\x61gent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x07\x61gentId\x12=\n\tpage_info\x18\x02 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x08pageInfo\"~\n\x11\x41gentInstanceList\x12\x1f\n\x0btotal_count\x18\x01 \x01(\x05R\ntotalCount\x12H\n\x05items\x18\x02 \x03(\x0b\x32\x32.ai.stigmer.agentic.agentinstance.v1.AgentInstanceR\x05items\"\x94\x02\n\x19ListAgentInstancesRequest\x12\x19\n\x03org\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x03org\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32J.ai.stigmer.agentic.agentinstance.v1.ListAgentInstancesRequest.LabelsEntryR\x06labels\x12=\n\tpage_info\x18\x03 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x08pageInfo\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xe3\x01\n\'com.ai.stigmer.agentic.agentinstance.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02#Ai.Stigmer.Agentic.Agentinstance.V1\xca\x02#Ai\\Stigmer\\Agentic\\Agentinstance\\V1\xe2\x02/Ai\\Stigmer\\Agentic\\Agentinstance\\V1\\GPBMetadata\xea\x02\'Ai::Stigmer::Agentic::Agentinstance::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentinstance.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.ai.stigmer.agentic.agentinstance.v1B\007IoProtoP\001\242\002\004ASAA\252\002#Ai.Stigmer.Agentic.Agentinstance.V1\312\002#Ai\\Stigmer\\Agentic\\Agentinstance\\V1\342\002/Ai\\Stigmer\\Agentic\\Agentinstance\\V1\\GPBMetadata\352\002\'Ai::Stigmer::Agentic::Agentinstance::V1'
  _globals['_AGENTINSTANCEID'].fields_by_name['value']._loaded_options = None
  _globals['_AGENTINSTANCEID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETAGENTINSTANCESBYAGENTREQUEST'].fields_by_name['agent_id']._loaded_options = None
  _globals['_GETAGENTINSTANCESBYAGENTREQUEST'].fields_by_name['agent_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_LISTAGENTINSTANCESREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_LISTAGENTINSTANCESREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LISTAGENTINSTANCESREQUEST'].fields_by_name['org']._loaded_options = None
  _globals['_LISTAGENTINSTANCESREQUEST'].fields_by_name['org']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_AGENTINSTANCEID']._serialized_start=202
  _globals['_AGENTINSTANCEID']._serialized_end=249
  _globals['_GETAGENTINSTANCESBYAGENTREQUEST']._serialized_start=252
  _globals['_GETAGENTINSTANCESBYAGENTREQUEST']._serialized_end=383
  _globals['_AGENTINSTANCELIST']._serialized_start=385
  _globals['_AGENTINSTANCELIST']._serialized_end=511
  _globals['_LISTAGENTINSTANCESREQUEST']._serialized_start=514
  _globals['_LISTAGENTINSTANCESREQUEST']._serialized_end=790
  _globals['_LISTAGENTINSTANCESREQUEST_LABELSENTRY']._serialized_start=733
  _globals['_LISTAGENTINSTANCESREQUEST_LABELSENTRY']._serialized_end=790
# @@protoc_insertion_point(module_scope)
