# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/iampolicy/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/iampolicy/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_api__pb2
from ai.stigmer.iam.iampolicy.v1 import io_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ai/stigmer/iam/iampolicy/v1/query.proto\x12\x1b\x61i.stigmer.iam.iampolicy.v1\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a%ai/stigmer/iam/iampolicy/v1/api.proto\x1a$ai/stigmer/iam/iampolicy/v1/io.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xc8\x05\n\x18IamPolicyQueryController\x12\x85\x01\n\x03get\x12(.ai.stigmer.iam.iampolicy.v1.IamPolicyId\x1a&.ai.stigmer.iam.iampolicy.v1.IamPolicy\",\xc2\xb8\x18(\x08\t*$unauthorized to view access policies\x12\x87\x01\n\x12\x63heckAuthorization\x12\x34.ai.stigmer.iam.iampolicy.v1.CheckAuthorizationInput\x1a\x35.ai.stigmer.iam.iampolicy.v1.CheckAuthorizationResult\"\x04\xd0\xb8\x18\x01\x12\xc6\x01\n\x19listAuthorizedResourceIds\x12;.ai.stigmer.iam.iampolicy.v1.ListAuthorizedResourceIdsInput\x1a\x36.ai.stigmer.iam.iampolicy.v1.AuthorizedResourceIdsList\"4\xc2\xb8\x18\x30\x08\t*,unauthorized to view authorized resource ids\x12\xca\x01\n\x1alistAuthorizedPrincipalIds\x12<.ai.stigmer.iam.iampolicy.v1.ListAuthorizedPrincipalIdsInput\x1a\x37.ai.stigmer.iam.iampolicy.v1.AuthorizedPrincipalIdsList\"5\xc2\xb8\x18\x31\x08\t*-unauthorized to view authorized principal ids\x1a\x04\xa0\xff+\nB\xbe\x01\n\x1f\x63om.ai.stigmer.iam.iampolicy.v1B\nQueryProtoP\x01\xa2\x02\x04\x41SII\xaa\x02\x1b\x41i.Stigmer.Iam.Iampolicy.V1\xca\x02\x1b\x41i\\Stigmer\\Iam\\Iampolicy\\V1\xe2\x02\'Ai\\Stigmer\\Iam\\Iampolicy\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Iam::Iampolicy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.iampolicy.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.iam.iampolicy.v1B\nQueryProtoP\001\242\002\004ASII\252\002\033Ai.Stigmer.Iam.Iampolicy.V1\312\002\033Ai\\Stigmer\\Iam\\Iampolicy\\V1\342\002\'Ai\\Stigmer\\Iam\\Iampolicy\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Iam::Iampolicy::V1'
  _globals['_IAMPOLICYQUERYCONTROLLER']._loaded_options = None
  _globals['_IAMPOLICYQUERYCONTROLLER']._serialized_options = b'\240\377+\n'
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\030(\010\t*$unauthorized to view access policies'
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['checkAuthorization']._loaded_options = None
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['checkAuthorization']._serialized_options = b'\320\270\030\001'
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['listAuthorizedResourceIds']._loaded_options = None
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['listAuthorizedResourceIds']._serialized_options = b'\302\270\0300\010\t*,unauthorized to view authorized resource ids'
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['listAuthorizedPrincipalIds']._loaded_options = None
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['listAuthorizedPrincipalIds']._serialized_options = b'\302\270\0301\010\t*-unauthorized to view authorized principal ids'
  _globals['_IAMPOLICYQUERYCONTROLLER']._serialized_start=275
  _globals['_IAMPOLICYQUERYCONTROLLER']._serialized_end=987
# @@protoc_insertion_point(module_scope)
