# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/apikey/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/apikey/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.apikey.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_api__pb2
from ai.stigmer.iam.apikey.v1 import io_pb2 as ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_io__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ai/stigmer/iam/apikey/v1/command.proto\x12\x18\x61i.stigmer.iam.apikey.v1\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\"ai/stigmer/iam/apikey/v1/api.proto\x1a!ai/stigmer/iam/apikey/v1/io.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xfa\x02\n\x17\x41piKeyCommandController\x12R\n\x06\x63reate\x12 .ai.stigmer.iam.apikey.v1.ApiKey\x1a .ai.stigmer.iam.apikey.v1.ApiKey\"\x04\xd0\xb8\x18\x01\x12\x83\x01\n\x06update\x12 .ai.stigmer.iam.apikey.v1.ApiKey\x1a .ai.stigmer.iam.apikey.v1.ApiKey\"5\xc2\xb8\x18\x31\x08\x04\x10\x0c\"\x0bmetadata.id*\x1eunauthorized to update api key\x12\x7f\n\x06\x64\x65lete\x12\".ai.stigmer.iam.apikey.v1.ApiKeyId\x1a .ai.stigmer.iam.apikey.v1.ApiKey\"/\xc2\xb8\x18+\x08\x02\x10\x0c\"\x05value*\x1eunauthorized to delete api key\x1a\x04\xa0\xff+\x0c\x42\xb1\x01\n\x1c\x63om.ai.stigmer.iam.apikey.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SIA\xaa\x02\x18\x41i.Stigmer.Iam.Apikey.V1\xca\x02\x18\x41i\\Stigmer\\Iam\\Apikey\\V1\xe2\x02$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\xea\x02\x1c\x41i::Stigmer::Iam::Apikey::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.apikey.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.ai.stigmer.iam.apikey.v1B\014CommandProtoP\001\242\002\004ASIA\252\002\030Ai.Stigmer.Iam.Apikey.V1\312\002\030Ai\\Stigmer\\Iam\\Apikey\\V1\342\002$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\352\002\034Ai::Stigmer::Iam::Apikey::V1'
  _globals['_APIKEYCOMMANDCONTROLLER']._loaded_options = None
  _globals['_APIKEYCOMMANDCONTROLLER']._serialized_options = b'\240\377+\014'
  _globals['_APIKEYCOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_APIKEYCOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\320\270\030\001'
  _globals['_APIKEYCOMMANDCONTROLLER'].methods_by_name['update']._loaded_options = None
  _globals['_APIKEYCOMMANDCONTROLLER'].methods_by_name['update']._serialized_options = b'\302\270\0301\010\004\020\014\"\013metadata.id*\036unauthorized to update api key'
  _globals['_APIKEYCOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_APIKEYCOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\030+\010\002\020\014\"\005value*\036unauthorized to delete api key'
  _globals['_APIKEYCOMMANDCONTROLLER']._serialized_start=265
  _globals['_APIKEYCOMMANDCONTROLLER']._serialized_end=643
# @@protoc_insertion_point(module_scope)
