# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/identityaccount/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/identityaccount/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.rpc import pagination_pb2 as ai_dot_stigmer_dot_commons_dot_rpc_dot_pagination__pb2
from ai.stigmer.iam.identityaccount.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ai/stigmer/iam/identityaccount/v1/io.proto\x12!ai.stigmer.iam.identityaccount.v1\x1a\'ai/stigmer/commons/rpc/pagination.proto\x1a+ai/stigmer/iam/identityaccount/v1/api.proto\x1a\x1b\x62uf/validate/validate.proto\"`\n\x10IdentityAccounts\x12L\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x32.ai.stigmer.iam.identityaccount.v1.IdentityAccountR\x07\x65ntries\"1\n\x11IdentityAccountId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"4\n\x14IdentityAccountEmail\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"%\n\x05IdpId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\x84\x01\n\x1cListWithIdentityAccountIdReq\x12.\n\x13identity_account_id\x18\x01 \x01(\tR\x11identityAccountId\x12\x34\n\x04page\x18\x02 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x04page\"\x85\x01\n\x14IdentityAccountsList\x12\x1f\n\x0btotal_pages\x18\x01 \x01(\x05R\ntotalPages\x12L\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x32.ai.stigmer.iam.identityaccount.v1.IdentityAccountR\x07\x65ntries\"]\n\x13ListWithIdentityOrg\x12\x10\n\x03org\x18\x01 \x01(\tR\x03org\x12\x34\n\x04page\x18\x02 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x04pageB\xd9\x01\n%com.ai.stigmer.iam.identityaccount.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SII\xaa\x02!Ai.Stigmer.Iam.Identityaccount.V1\xca\x02!Ai\\Stigmer\\Iam\\Identityaccount\\V1\xe2\x02-Ai\\Stigmer\\Iam\\Identityaccount\\V1\\GPBMetadata\xea\x02%Ai::Stigmer::Iam::Identityaccount::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.identityaccount.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.ai.stigmer.iam.identityaccount.v1B\007IoProtoP\001\242\002\004ASII\252\002!Ai.Stigmer.Iam.Identityaccount.V1\312\002!Ai\\Stigmer\\Iam\\Identityaccount\\V1\342\002-Ai\\Stigmer\\Iam\\Identityaccount\\V1\\GPBMetadata\352\002%Ai::Stigmer::Iam::Identityaccount::V1'
  _globals['_IDENTITYACCOUNTID'].fields_by_name['value']._loaded_options = None
  _globals['_IDENTITYACCOUNTID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_IDENTITYACCOUNTEMAIL'].fields_by_name['value']._loaded_options = None
  _globals['_IDENTITYACCOUNTEMAIL'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_IDPID'].fields_by_name['value']._loaded_options = None
  _globals['_IDPID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_IDENTITYACCOUNTS']._serialized_start=196
  _globals['_IDENTITYACCOUNTS']._serialized_end=292
  _globals['_IDENTITYACCOUNTID']._serialized_start=294
  _globals['_IDENTITYACCOUNTID']._serialized_end=343
  _globals['_IDENTITYACCOUNTEMAIL']._serialized_start=345
  _globals['_IDENTITYACCOUNTEMAIL']._serialized_end=397
  _globals['_IDPID']._serialized_start=399
  _globals['_IDPID']._serialized_end=436
  _globals['_LISTWITHIDENTITYACCOUNTIDREQ']._serialized_start=439
  _globals['_LISTWITHIDENTITYACCOUNTIDREQ']._serialized_end=571
  _globals['_IDENTITYACCOUNTSLIST']._serialized_start=574
  _globals['_IDENTITYACCOUNTSLIST']._serialized_end=707
  _globals['_LISTWITHIDENTITYORG']._serialized_start=709
  _globals['_LISTWITHIDENTITYORG']._serialized_end=802
# @@protoc_insertion_point(module_scope)
