# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/platform/github/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/platform/github/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ai/stigmer/platform/github/v1/service.proto\x12\x1d\x61i.stigmer.platform.github.v1\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto\x1a\x1b\x62uf/validate/validate.proto\"I\n\x1bGetOAuthAuthorizeUrlRequest\x12*\n\x0credirect_uri\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0bredirectUri\"Y\n\x1cGetOAuthAuthorizeUrlResponse\x12#\n\rauthorize_url\x18\x01 \x01(\tR\x0c\x61uthorizeUrl\x12\x14\n\x05state\x18\x02 \x01(\tR\x05state\"\x82\x01\n\x18\x45xchangeOAuthCodeRequest\x12\x1b\n\x04\x63ode\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x04\x63ode\x12\x1d\n\x05state\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x05state\x12*\n\x0credirect_uri\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0bredirectUri\"s\n\x19\x45xchangeOAuthCodeResponse\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12\x1d\n\ntoken_type\x18\x02 \x01(\tR\ttokenType\x12\x14\n\x05scope\x18\x03 \x01(\tR\x05scope2\xb6\x02\n\rGitHubService\x12\x95\x01\n\x14getOAuthAuthorizeUrl\x12:.ai.stigmer.platform.github.v1.GetOAuthAuthorizeUrlRequest\x1a;.ai.stigmer.platform.github.v1.GetOAuthAuthorizeUrlResponse\"\x04\xd0\xb8\x18\x01\x12\x8c\x01\n\x11\x65xchangeOAuthCode\x12\x37.ai.stigmer.platform.github.v1.ExchangeOAuthCodeRequest\x1a\x38.ai.stigmer.platform.github.v1.ExchangeOAuthCodeResponse\"\x04\xd0\xb8\x18\x01\x42\xca\x01\n!com.ai.stigmer.platform.github.v1B\x0cServiceProtoP\x01\xa2\x02\x04\x41SPG\xaa\x02\x1d\x41i.Stigmer.Platform.Github.V1\xca\x02\x1d\x41i\\Stigmer\\Platform\\Github\\V1\xe2\x02)Ai\\Stigmer\\Platform\\Github\\V1\\GPBMetadata\xea\x02!Ai::Stigmer::Platform::Github::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.platform.github.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.ai.stigmer.platform.github.v1B\014ServiceProtoP\001\242\002\004ASPG\252\002\035Ai.Stigmer.Platform.Github.V1\312\002\035Ai\\Stigmer\\Platform\\Github\\V1\342\002)Ai\\Stigmer\\Platform\\Github\\V1\\GPBMetadata\352\002!Ai::Stigmer::Platform::Github::V1'
  _globals['_GETOAUTHAUTHORIZEURLREQUEST'].fields_by_name['redirect_uri']._loaded_options = None
  _globals['_GETOAUTHAUTHORIZEURLREQUEST'].fields_by_name['redirect_uri']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_EXCHANGEOAUTHCODEREQUEST'].fields_by_name['code']._loaded_options = None
  _globals['_EXCHANGEOAUTHCODEREQUEST'].fields_by_name['code']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_EXCHANGEOAUTHCODEREQUEST'].fields_by_name['state']._loaded_options = None
  _globals['_EXCHANGEOAUTHCODEREQUEST'].fields_by_name['state']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_EXCHANGEOAUTHCODEREQUEST'].fields_by_name['redirect_uri']._loaded_options = None
  _globals['_EXCHANGEOAUTHCODEREQUEST'].fields_by_name['redirect_uri']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GITHUBSERVICE'].methods_by_name['getOAuthAuthorizeUrl']._loaded_options = None
  _globals['_GITHUBSERVICE'].methods_by_name['getOAuthAuthorizeUrl']._serialized_options = b'\320\270\030\001'
  _globals['_GITHUBSERVICE'].methods_by_name['exchangeOAuthCode']._loaded_options = None
  _globals['_GITHUBSERVICE'].methods_by_name['exchangeOAuthCode']._serialized_options = b'\320\270\030\001'
  _globals['_GETOAUTHAUTHORIZEURLREQUEST']._serialized_start=174
  _globals['_GETOAUTHAUTHORIZEURLREQUEST']._serialized_end=247
  _globals['_GETOAUTHAUTHORIZEURLRESPONSE']._serialized_start=249
  _globals['_GETOAUTHAUTHORIZEURLRESPONSE']._serialized_end=338
  _globals['_EXCHANGEOAUTHCODEREQUEST']._serialized_start=341
  _globals['_EXCHANGEOAUTHCODEREQUEST']._serialized_end=471
  _globals['_EXCHANGEOAUTHCODERESPONSE']._serialized_start=473
  _globals['_EXCHANGEOAUTHCODERESPONSE']._serialized_end=588
  _globals['_GITHUBSERVICE']._serialized_start=591
  _globals['_GITHUBSERVICE']._serialized_end=901
# @@protoc_insertion_point(module_scope)
