# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/tenancy/project/v1/status.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/tenancy/project/v1/status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import status_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ai/stigmer/tenancy/project/v1/status.proto\x12\x1d\x61i.stigmer.tenancy.project.v1\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a+ai/stigmer/commons/apiresource/status.proto\"\x87\x02\n\x15ReconciliationSummary\x12N\n\x07\x63reated\x18\x01 \x03(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceR\x07\x63reated\x12N\n\x07updated\x18\x02 \x03(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceR\x07updated\x12N\n\x07\x64\x65leted\x18\x03 \x03(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceR\x07\x64\x65leted\"\xbe\x01\n\rProjectStatus\x12\x65\n\x13last_reconciliation\x18\x01 \x01(\x0b\x32\x34.ai.stigmer.tenancy.project.v1.ReconciliationSummaryR\x12lastReconciliation\x12\x46\n\x05\x61udit\x18\x63 \x01(\x0b\x32\x30.ai.stigmer.commons.apiresource.ApiResourceAuditR\x05\x61uditB\xc9\x01\n!com.ai.stigmer.tenancy.project.v1B\x0bStatusProtoP\x01\xa2\x02\x04\x41STP\xaa\x02\x1d\x41i.Stigmer.Tenancy.Project.V1\xca\x02\x1d\x41i\\Stigmer\\Tenancy\\Project\\V1\xe2\x02)Ai\\Stigmer\\Tenancy\\Project\\V1\\GPBMetadata\xea\x02!Ai::Stigmer::Tenancy::Project::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.tenancy.project.v1.status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.ai.stigmer.tenancy.project.v1B\013StatusProtoP\001\242\002\004ASTP\252\002\035Ai.Stigmer.Tenancy.Project.V1\312\002\035Ai\\Stigmer\\Tenancy\\Project\\V1\342\002)Ai\\Stigmer\\Tenancy\\Project\\V1\\GPBMetadata\352\002!Ai::Stigmer::Tenancy::Project::V1'
  _globals['_RECONCILIATIONSUMMARY']._serialized_start=164
  _globals['_RECONCILIATIONSUMMARY']._serialized_end=427
  _globals['_PROJECTSTATUS']._serialized_start=430
  _globals['_PROJECTSTATUS']._serialized_end=620
# @@protoc_insertion_point(module_scope)
