# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/tenancy/organization/v1/api.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/tenancy/organization/v1/api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import metadata_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_metadata__pb2
from ai.stigmer.commons.apiresource import status_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_status__pb2
from ai.stigmer.tenancy.organization.v1 import spec_pb2 as ai_dot_stigmer_dot_tenancy_dot_organization_dot_v1_dot_spec__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ai/stigmer/tenancy/organization/v1/api.proto\x12\"ai.stigmer.tenancy.organization.v1\x1a-ai/stigmer/commons/apiresource/metadata.proto\x1a+ai/stigmer/commons/apiresource/status.proto\x1a-ai/stigmer/tenancy/organization/v1/spec.proto\x1a\x1b\x62uf/validate/validate.proto\"\xdd\x05\n\x0cOrganization\x12=\n\x0b\x61pi_version\x18\x01 \x01(\tB\x1c\xbaH\x19r\x17\n\x15tenancy.stigmer.ai/v1R\napiVersion\x12\'\n\x04kind\x18\x02 \x01(\tB\x13\xbaH\x10r\x0e\n\x0cOrganizationR\x04kind\x12\xca\x03\n\x08metadata\x18\x03 \x01(\x0b\x32\x33.ai.stigmer.commons.apiresource.ApiResourceMetadataB\xf8\x02\xbaH\xf4\x02\xba\x01\x81\x01\n\x13metadata.slug.chars\x12Gmetadata.slug: Only lowercase letters, numbers, and hyphens are allowed\x1a!this.slug.matches(\'^[a-z0-9-]+$\')\xba\x01h\n\x13metadata.slug.start\x12\x31metadata.slug: Must start with a lowercase letter\x1a\x1ethis.slug.matches(\'^[a-z].*$\')\xba\x01~\n\x14metadata.slug.length\x12\x37metadata.slug: Must be between 2 and 15 characters long\x1a-size(this.slug) >= 2 && size(this.slug) <= 15\xc8\x01\x01R\x08metadata\x12H\n\x04spec\x18\x04 \x01(\x0b\x32\x34.ai.stigmer.tenancy.organization.v1.OrganizationSpecR\x04spec\x12N\n\x06status\x18\x05 \x01(\x0b\x32\x36.ai.stigmer.commons.apiresource.ApiResourceAuditStatusR\x06statusB\xdf\x01\n&com.ai.stigmer.tenancy.organization.v1B\x08\x41piProtoP\x01\xa2\x02\x04\x41STO\xaa\x02\"Ai.Stigmer.Tenancy.Organization.V1\xca\x02\"Ai\\Stigmer\\Tenancy\\Organization\\V1\xe2\x02.Ai\\Stigmer\\Tenancy\\Organization\\V1\\GPBMetadata\xea\x02&Ai::Stigmer::Tenancy::Organization::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.tenancy.organization.v1.api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.ai.stigmer.tenancy.organization.v1B\010ApiProtoP\001\242\002\004ASTO\252\002\"Ai.Stigmer.Tenancy.Organization.V1\312\002\"Ai\\Stigmer\\Tenancy\\Organization\\V1\342\002.Ai\\Stigmer\\Tenancy\\Organization\\V1\\GPBMetadata\352\002&Ai::Stigmer::Tenancy::Organization::V1'
  _globals['_ORGANIZATION'].fields_by_name['api_version']._loaded_options = None
  _globals['_ORGANIZATION'].fields_by_name['api_version']._serialized_options = b'\272H\031r\027\n\025tenancy.stigmer.ai/v1'
  _globals['_ORGANIZATION'].fields_by_name['kind']._loaded_options = None
  _globals['_ORGANIZATION'].fields_by_name['kind']._serialized_options = b'\272H\020r\016\n\014Organization'
  _globals['_ORGANIZATION'].fields_by_name['metadata']._loaded_options = None
  _globals['_ORGANIZATION'].fields_by_name['metadata']._serialized_options = b'\272H\364\002\272\001\201\001\n\023metadata.slug.chars\022Gmetadata.slug: Only lowercase letters, numbers, and hyphens are allowed\032!this.slug.matches(\'^[a-z0-9-]+$\')\272\001h\n\023metadata.slug.start\0221metadata.slug: Must start with a lowercase letter\032\036this.slug.matches(\'^[a-z].*$\')\272\001~\n\024metadata.slug.length\0227metadata.slug: Must be between 2 and 15 characters long\032-size(this.slug) >= 2 && size(this.slug) <= 15\310\001\001'
  _globals['_ORGANIZATION']._serialized_start=253
  _globals['_ORGANIZATION']._serialized_end=986
# @@protoc_insertion_point(module_scope)
