# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/apiresource/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/apiresource/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_apiresourcekind_dot_api__resource__kind__pb2
from ai.stigmer.commons.apiresource import enum_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_enum__pb2
from ai.stigmer.commons.rpc import pagination_pb2 as ai_dot_stigmer_dot_commons_dot_rpc_dot_pagination__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ai/stigmer/commons/apiresource/io.proto\x12\x1e\x61i.stigmer.commons.apiresource\x1a\x46\x61i/stigmer/commons/apiresource/apiresourcekind/api_resource_kind.proto\x1a)ai/stigmer/commons/apiresource/enum.proto\x1a\'ai/stigmer/commons/rpc/pagination.proto\x1a\x1b\x62uf/validate/validate.proto\"-\n\rApiResourceId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\x80\x01\n\x16\x41piResourceDeleteInput\x12\'\n\x0bresource_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\nresourceId\x12\'\n\x0fversion_message\x18\x02 \x01(\tR\x0eversionMessage\x12\x14\n\x05\x66orce\x18\x03 \x01(\x08R\x05\x66orce\"U\n\x1d\x41piResourceByOrgBySlugRequest\x12\x18\n\x03org\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x03org\x12\x1a\n\x04slug\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04slug\"\xbb\x01\n\x17\x46indApiResourcesRequest\x12\x18\n\x03org\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x03org\x12\x12\n\x04kind\x18\x03 \x01(\tR\x04kind\x12\x34\n\x04page\x18\x04 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x04page\x12\x1f\n\x0bpage_number\x18\x05 \x01(\x05R\npageNumber\x12\x1b\n\tpage_size\x18\x06 \x01(\x05R\x08pageSize\"\xa3\x01\n\x15UpdateVisibilityInput\x12\'\n\x0bresource_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\nresourceId\x12\x61\n\nvisibility\x18\x02 \x01(\x0e\x32\x35.ai.stigmer.commons.apiresource.ApiResourceVisibilityB\n\xbaH\x07\x82\x01\x04\x10\x01 \x00R\nvisibility\"\xa0\x02\n\x14\x41piResourceReference\x12/\n\x03org\x18\x01 \x01(\tB\x1d\xbaH\x1ar\x18\x18?2\x14^$|^[a-z][a-z0-9-]*$R\x03org\x12S\n\x04kind\x18\x02 \x01(\x0e\x32?.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceKindR\x04kind\x12\x33\n\x04slug\x18\x03 \x01(\tB\x1f\xbaH\x1cr\x17\x10\x01\x18?2\x11^[a-z][a-z0-9-]*$\xc8\x01\x01R\x04slug\x12M\n\x07version\x18\x04 \x01(\tB3\xbaH0r.2,^$|^latest$|^[a-zA-Z0-9._-]+$|^[a-f0-9]{64}$R\x07versionB\xc9\x01\n\"com.ai.stigmer.commons.apiresourceB\x07IoProtoP\x01\xa2\x02\x04\x41SCA\xaa\x02\x1e\x41i.Stigmer.Commons.Apiresource\xca\x02\x1e\x41i\\Stigmer\\Commons\\Apiresource\xe2\x02*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\xea\x02!Ai::Stigmer::Commons::Apiresourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.apiresource.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.ai.stigmer.commons.apiresourceB\007IoProtoP\001\242\002\004ASCA\252\002\036Ai.Stigmer.Commons.Apiresource\312\002\036Ai\\Stigmer\\Commons\\Apiresource\342\002*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\352\002!Ai::Stigmer::Commons::Apiresource'
  _globals['_APIRESOURCEID'].fields_by_name['value']._loaded_options = None
  _globals['_APIRESOURCEID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_APIRESOURCEDELETEINPUT'].fields_by_name['resource_id']._loaded_options = None
  _globals['_APIRESOURCEDELETEINPUT'].fields_by_name['resource_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_APIRESOURCEBYORGBYSLUGREQUEST'].fields_by_name['org']._loaded_options = None
  _globals['_APIRESOURCEBYORGBYSLUGREQUEST'].fields_by_name['org']._serialized_options = b'\272H\003\310\001\001'
  _globals['_APIRESOURCEBYORGBYSLUGREQUEST'].fields_by_name['slug']._loaded_options = None
  _globals['_APIRESOURCEBYORGBYSLUGREQUEST'].fields_by_name['slug']._serialized_options = b'\272H\003\310\001\001'
  _globals['_FINDAPIRESOURCESREQUEST'].fields_by_name['org']._loaded_options = None
  _globals['_FINDAPIRESOURCESREQUEST'].fields_by_name['org']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEVISIBILITYINPUT'].fields_by_name['resource_id']._loaded_options = None
  _globals['_UPDATEVISIBILITYINPUT'].fields_by_name['resource_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEVISIBILITYINPUT'].fields_by_name['visibility']._loaded_options = None
  _globals['_UPDATEVISIBILITYINPUT'].fields_by_name['visibility']._serialized_options = b'\272H\007\202\001\004\020\001 \000'
  _globals['_APIRESOURCEREFERENCE'].fields_by_name['org']._loaded_options = None
  _globals['_APIRESOURCEREFERENCE'].fields_by_name['org']._serialized_options = b'\272H\032r\030\030?2\024^$|^[a-z][a-z0-9-]*$'
  _globals['_APIRESOURCEREFERENCE'].fields_by_name['slug']._loaded_options = None
  _globals['_APIRESOURCEREFERENCE'].fields_by_name['slug']._serialized_options = b'\272H\034r\027\020\001\030?2\021^[a-z][a-z0-9-]*$\310\001\001'
  _globals['_APIRESOURCEREFERENCE'].fields_by_name['version']._loaded_options = None
  _globals['_APIRESOURCEREFERENCE'].fields_by_name['version']._serialized_options = b'\272H0r.2,^$|^latest$|^[a-zA-Z0-9._-]+$|^[a-f0-9]{64}$'
  _globals['_APIRESOURCEID']._serialized_start=260
  _globals['_APIRESOURCEID']._serialized_end=305
  _globals['_APIRESOURCEDELETEINPUT']._serialized_start=308
  _globals['_APIRESOURCEDELETEINPUT']._serialized_end=436
  _globals['_APIRESOURCEBYORGBYSLUGREQUEST']._serialized_start=438
  _globals['_APIRESOURCEBYORGBYSLUGREQUEST']._serialized_end=523
  _globals['_FINDAPIRESOURCESREQUEST']._serialized_start=526
  _globals['_FINDAPIRESOURCESREQUEST']._serialized_end=713
  _globals['_UPDATEVISIBILITYINPUT']._serialized_start=716
  _globals['_UPDATEVISIBILITYINPUT']._serialized_end=879
  _globals['_APIRESOURCEREFERENCE']._serialized_start=882
  _globals['_APIRESOURCEREFERENCE']._serialized_end=1170
# @@protoc_insertion_point(module_scope)
